# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

import typing
from importlib import import_module

if typing.TYPE_CHECKING:
    from .types import (
        AccessGrantListResponse,
        AccessGrantResponse,
        AccessItem,
        AccessLevel,
        AccessOverviewGrant,
        AccessOverviewResponse,
        AccessOverviewSlice,
        AccessOverviewStore,
        AccessRightGrantRequest,
        AccessRightListResponse,
        AccessRightResponse,
        ActionItemListResponse,
        ActionItemResponse,
        ActionItemsOverviewResponse,
        ActiveSessionSummary,
        ActivityLogEntry,
        ActivityLogResponse,
        AddThreadToSpaceResponse,
        AddToVectorStoreResponse,
        AddVectorStoreToSpaceResponse,
        ApiKeyActionResponse,
        ApiKeyCreateResponse,
        ApiKeyDailyUsageResponse,
        ApiKeyLimit,
        ApiKeyListResponse,
        ApiKeyResponse,
        ApiKeyRotateResponse,
        ApiKeyUsageDetail,
        ApiKeyUsageSummary,
        ApiLimits,
        AppApiV1SchemasAssistantsAuditLogListResponse,
        AppApiV1SchemasAuditLogV2AuditLogListResponse,
        AppApiV1SchemasKnowledgeStoreFilesProcessingStatusResponse,
        AppApiV1SchemasMeetingBuddyAnalyticsTopicItem,
        AppApiV1SchemasMeetingBuddySearchTopicItem,
        AppApiV1SchemasMeetingBuddySearchTopicListResponse,
        AppApiV1SchemasMeetingBuddyTopicListResponse,
        AppApiV1SchemasVectorStoreFileProcessingStatusResponse,
        ApplyMode,
        AssignRoleMemberResponse,
        AssistantActiveSessionResponse,
        AssistantListResponse,
        AssistantListResponseAssistantsItem,
        AssistantMbpConfigResponse,
        AssistantResponse,
        AssistantSelection,
        AssistantStandardResponse,
        AssistantSummaryResponse,
        AttachmentCreateInline,
        AttachmentDeleteResponse,
        AttachmentListResponse,
        AttachmentResponse,
        AttachmentSummary,
        AudioModelInfo,
        AuditEntryResponse,
        AuditLogEntry,
        AuditLogResponse,
        AuditLogSchema,
        AuthConfigInfo,
        AuthFieldSchema,
        AuthModeResponse,
        AuthSchemaResponse,
        AuthorizationResponse,
        AutoJoinRuleListResponse,
        AutoJoinRuleResponse,
        AvailableConnectorsResponse,
        AvatarListResponse,
        AvatarResponse,
        Base64FileUpload,
        BatchExtractResponse,
        BatchScrapeOptions,
        BreakdownItem,
        BreakdownResponse,
        BriefingResponse,
        BulkGrantEntry,
        BulkOperationResponse,
        CalendarConnectionListResponse,
        CalendarConnectionResponse,
        CalendarEventListResponse,
        CalendarEventResponse,
        CalendarSyncResponse,
        CancelStreamResponse,
        CapabilityMetadataResponse,
        CategoryStatistics,
        CategoryStatisticsResponse,
        ChangeDetail,
        ChangeLogListResponse,
        ChangeLogRequest,
        ChangeLogResponse,
        ChangePresetResponse,
        ChangeSchema,
        CheckExistsResponse,
        CheckUsernameResponse,
        ChunkedUploadResponse,
        ClearAllCachesResponse,
        ClearAllCachesResponseCachesClearedValue,
        CoachingScoreResponse,
        CompetitorListResponse,
        CompetitorMentionListResponse,
        CompetitorMentionResponse,
        CompleteInvitationResponse,
        CompleteOAuthResponse,
        ComponentStatus,
        ComposioSyncResponse,
        ComposioSyncStatusResponse,
        CompositeMemberMapping,
        ConfidenceBucket,
        ConfidenceMetrics,
        ConfidenceTrendPoint,
        ConfigFieldDescriptor,
        ConfigFieldDescriptorMaximum,
        ConfigFieldDescriptorMinimum,
        ConfigFieldType,
        ConfigSelectOption,
        ConnectCalendarOAuthResponse,
        ConnectionConfigOptionsResponse,
        ConnectionInfo,
        ConnectionTestResult,
        ConnectionsResponse,
        ConnectorInfo,
        ConnectorResponse,
        ConnectorToolsResponse,
        ConsentRecordResponse,
        ConsentSummary,
        ConvertToWorkflowResponse,
        CountryResponse,
        CreateFlowplateKeyResponse,
        CredentialHealthStatus,
        CredentialTestRequest,
        CredentialTestResult,
        DailyApiKeyUsage,
        DataExportActionItem,
        DataExportConsentRecord,
        DataExportIntelligence,
        DataExportResponse,
        DataExportSession,
        DataExportTranscript,
        DateFilter,
        DealListResponse,
        DealSummaryResponse,
        DealTimelineEntry,
        DealTimelineResponse,
        DealTrackingResponse,
        DecisionListResponse,
        DecisionResponse,
        DecisionsResponse,
        DeleteAllThreadsResponse,
        DeleteConnectionResponse,
        DeleteMessageResponse,
        DepartmentMemberResponse,
        DepartmentMembership,
        DepartmentResponse,
        DepartmentTreeResponse,
        DetachWorkflowResponse,
        DetailedHealthCheck,
        DeviceInformation,
        DeviceSessionResponse,
        DiarizeResponse,
        DocumentExtractResponse,
        DurationBucket,
        DurationDistributionResponse,
        EffectivePermissionsResponse,
        EffectivePermissionsResponseDepartmentScope,
        EmailValidationResponse,
        EmotionDetectionResponse,
        EngineType,
        EntityType,
        ExecutionLogEntry,
        ExecutionLogsResponse,
        ExecutionReturnMode,
        ExportRequest,
        FailedOperation,
        FailureAnalysisResponse,
        FailureItem,
        FileBatchUploadResponse,
        FileContentResponse,
        FileListResponse,
        FileReference,
        FileResponse,
        FileUploadConfigResponse,
        FiltersAppliedSchema,
        FlowplateKeyActionResponse,
        FrameworkListResponse,
        FunctionTool,
        GitSyncResponse,
        GitUploadResponse,
        GoogleAuthorizeResponse,
        GrantPathEntryResolved,
        GrantPathEntryResponse,
        HealthCheck,
        HealthResponse,
        HttpValidationError,
        IconListResponse,
        IconResponse,
        ImageAnalyzeResponse,
        ImageUploadResponse,
        ImapConnectionResponse,
        ImapFooterResponse,
        InputMessage,
        InputMessageContent,
        IntelligenceConfigListResponse,
        IntelligenceConfigResponse,
        IntelligenceFeatures,
        IntelligenceResponse,
        InvalidateLimitCacheResponse,
        InvitationDetailsResponse,
        InvitationResponse,
        JobListResponse,
        JobMetadata,
        JobStatus,
        JobStatusResponse,
        JoinAllToggleResponse,
        KnowledgeSliceListResponse,
        KnowledgeSliceResponse,
        KnowledgeVectorStoreCreate,
        KnowledgeVectorStoreListResponse,
        KnowledgeVectorStoreResponse,
        LimitUpdateResponse,
        LimitsSummary,
        ListAuthConfigsResponse,
        LiveConfigResponse,
        LiveInteractionListResponse,
        LiveInteractionResponse,
        LiveMessageResponse,
        LlmMode,
        LoginRequest,
        LoginResponse,
        LoginVerificationResponse,
        LogoutResponse,
        ManualUploadResponse,
        McpConfigurationListResponse,
        McpConfigurationResponse,
        McpServerInfo,
        McpTool,
        McpToolSchema,
        McpToolSchemaAllowedTools,
        McpToolSchemaRequireApproval,
        MeetingTypeDistributionResponse,
        MeetingTypeItem,
        MemberListResponse,
        MemberResponse,
        MessageInput,
        MessageInputRole,
        MessageResponse,
        MessageResponseRole,
        MessagesListResponse,
        MiniChatPosition,
        MiniChatSettingsData,
        MiniChatSettingsPayload,
        MiniChatSettingsResponse,
        ModelCompatibilityResponse,
        ModelPricing,
        ModelReasoningOptionsResponse,
        ModelResponse,
        ModelsListResponse,
        MyAccessResponse,
        NeuronsAnalyticsDashboardResponse,
        NeuronsBenchmarksResponse,
        NeuronsHeatmapResponse,
        NeuronsOptimizationResponse,
        NeuronsTrendsResponse,
        OAuthConfigOptionsResponse,
        OAuthCredentialsResponse,
        OpenNewChats,
        OrgCalendarConnectionListResponse,
        OrgCalendarConnectionResponse,
        OrgSettingsResponse,
        OrganizationBasicInfo,
        OrganizationDomainResponse,
        OrganizationInfo,
        OrganizationLimits,
        OrganizationListResponse,
        OrganizationModelSettingsResponse,
        OrganizationResponse,
        OutputModeInfo,
        OutputModesResponse,
        OwnedResource,
        PaginationSchema,
        PartialContext,
        PartialToolCall,
        ParticipantDuration,
        ParticipantStat,
        ParticipantsResponse,
        PasswordResetResponse,
        PasswordResetVerifyResponse,
        PasswordUpdateResponse,
        PermissionPresetResponse,
        PersonalConnectorTool,
        PiiSettingsResponse,
        PinThreadResponse,
        PipelineProcessingDetails,
        PipelineRecordResult,
        PipelineRecordResultStatus,
        PipelineSuccessResponse,
        PresetInfo,
        PricingTierResponse,
        PrivacySettings,
        ProcessingLogEntry,
        ProcessingLogsResponse,
        PromoteToAssistantResponse,
        PromptModule,
        ProviderResponse,
        ProviderValidationResponse,
        PublicChatHistoryMessage,
        PublicChatHistoryResponse,
        PublicChatResponse,
        PublicChatStatusResponse,
        PublicTranscriptResponse,
        PublicTranscriptSegment,
        QualityMetricsResponse,
        ReasoningConfig,
        ReasoningConfigEffort,
        ReasoningConfigSchema,
        ReasoningConfigSchemaEffort,
        ReasoningConfigSchemaSummary,
        ReasoningConfigSummary,
        ReasoningEffortOption,
        ReasoningLevelInfo,
        ReasoningLevelsResponse,
        RecentDecision,
        RecordingInfoResponse,
        RefreshFlowplateKeyResponse,
        RefreshTokenResponse,
        RegenerateEmailResponse,
        RegisterResponse,
        RemoveUserRequest,
        RenameConnectionResponse,
        ResendCodeResponse,
        ResetToNewChat,
        ResolvedAccessResponse,
        RetentionPolicyResponse,
        RevenueIntelligenceResponse,
        RoleInfo,
        RoleMemberResponse,
        RoleMembersListResponse,
        RoleResponse,
        RoleResponsePermissions,
        RoleTemplateResponse,
        RuleCategory,
        RuleDetailResponse,
        RuleListPaginatedResponse,
        RuleListPaginatedResponseFiltersValue,
        RuleListResponse,
        RuleScope,
        RuleScopeApi,
        RuleSummary,
        RuleType,
        ScrapeOptions,
        ScrapeResponse,
        SearchFilters,
        SearchResponse,
        SearchResult,
        SentimentDataPoint,
        SentimentOverall,
        SentimentTrendsResponse,
        SessionChatHistoryResponse,
        SessionChatMessage,
        SessionConsentResponse,
        SessionListResponse,
        SessionParticipantEvent,
        SessionParticipantsResponse,
        SessionResponse,
        SessionSpeakerBreakdownResponse,
        SessionSpeakerDetail,
        SetCurrentOrganizationResponse,
        ShareTokenCreate,
        SharedResource,
        SiteAnalysisResponse,
        SliceAccessEntry,
        SliceStoreMapping,
        SpaceListResponse,
        SpaceResponse,
        SpaceThreadListResponse,
        SpaceVectorStoreEntry,
        SpaceVectorStoreListResponse,
        SpeakerAnalysis,
        SpeakerDetail,
        SpeakerEmbeddingListResponse,
        SpeakerEmbeddingResponse,
        SpeakerIdentifyResponse,
        SpeakerInfo,
        SpeakerStat,
        SpeakerStatsResponse,
        SpeakersResponse,
        StatusCount,
        StatusInfo,
        StatusResponse,
        StatusSummaryResponse,
        StorageUsageResponse,
        StoreAccessEntry,
        StoreFileDetailResponse,
        StoreFileListItem,
        StoreFileListResponse,
        StoreFileUploadResponse,
        StoreUsageEntry,
        StreamlineAutomationListResponse,
        StreamlineAutomationResponse,
        StreamlineExecutionListResponse,
        StreamlineExecutionResponse,
        StreamlineGitSyncJobListResponse,
        StreamlineGitSyncJobResponse,
        SuccessResponseDict,
        SuccessResponseListVectorStoreResponse,
        SuccessResponseProcessingStatusResponse,
        SuccessResponseVectorStoreFileListResponse,
        SuccessResponseVectorStoreFileResponse,
        SuccessResponseVectorStoreResponse,
        SuccessResponseVectorStoreUsageResponse,
        SummaryOption,
        SummaryResponse,
        SupportedFileCategory,
        SyncOperation,
        SyncOperationAction,
        SynthesizeRequest,
        SystemToolResponse,
        SystemToolSchema,
        SystemToolsListResponse,
        TeamScoreSummary,
        TeamSummaryResponse,
        ThreadListResponse,
        ThreadResponse,
        TimezoneResponse,
        ToggleConnectionResponse,
        TokenValidationResponse,
        ToolCapabilitiesResponse,
        ToolConfigurationSchema,
        ToolInfo,
        ToolParameterResponse,
        TopAssignee,
        TopicResponse,
        TopicSegmentResponse,
        TopicsResponse,
        TranscribeNowResponse,
        TranscribeResponse,
        TranscriptSegment,
        TranscriptionCreateRequest,
        TranscriptionOptions,
        TranscriptionStatsResponse,
        TrendDataPoint,
        TrendsResponse,
        TriggerConfigSchema,
        UiAccessActions,
        UiAccessPages,
        UiAccessResponse,
        UnsupportedFileCategory,
        UpdateMessageResponse,
        UpdateMessageResponseRole,
        UpdateProfileResponse,
        UpdateToolStatusResponse,
        UpdateUsernameResponse,
        UsageAnalyticsResponse,
        UsageByEntityType,
        UsageLimitsResponse,
        UsageStatisticsResponse,
        UsageSummaryResponse,
        UserAccessEntryResponse,
        UserBriefResponse,
        UserContextSchema,
        UserProfileResponse,
        UserResponse,
        UserV2Response,
        UsersWithAccessResponse,
        Utterance,
        ValidationError,
        ValidationErrorLocItem,
        VectorStoreBase64UploadResponse,
        VectorStoreFileListResponse,
        VectorStoreFileResponse,
        VectorStoreResponse,
        VectorStoreUsageItem,
        VectorStoreUsageResponse,
        VideoMetadataResponse,
        VideoQualityConfig,
        VoiceAgentStatusResponse,
        VoiceProfileListResponse,
        VoiceProfileResponse,
        WebhookConfig,
        WelcomeDetailsResponse,
        WorkflowExecutionResponse,
        WorkflowListResponse,
        WorkflowResponse,
        WorkflowTriggerResponse,
        WorkflowUpdate,
    )
    from .errors import (
        BadRequestError,
        ConflictError,
        ForbiddenError,
        InternalServerError,
        NotFoundError,
        NotImplementedError,
        TooManyRequestsError,
        UnauthorizedError,
        UnprocessableEntityError,
    )
    from . import (
        access_control,
        admin_cache,
        admin_connectors,
        analytics_api_keys,
        analytics_limits,
        analytics_usage,
        api_keys,
        assistant_mbp_configuration,
        assistants,
        audio,
        audio_services,
        audit_log_v2,
        authentication,
        avatars,
        config,
        connectors_data_pipeline,
        crew_management_admin,
        crew_management_invitations,
        crew_management_members,
        departments,
        document_extraction,
        entity_rules,
        files,
        flowplate_integration,
        health,
        icons,
        image_operations,
        knowledge,
        knowledge_connectors,
        mcp,
        mcp_configurations,
        meeting_buddy,
        meeting_buddy_analytics,
        meeting_buddy_auto_join,
        meeting_buddy_calendar,
        meeting_buddy_compliance,
        meeting_buddy_intelligence,
        meeting_buddy_intelligence_config,
        meeting_buddy_internal,
        meeting_buddy_knowledge,
        meeting_buddy_live_intelligence,
        meeting_buddy_note_taker,
        meeting_buddy_public,
        meeting_buddy_revenue_intelligence,
        meeting_buddy_settings,
        meeting_buddy_streaming,
        meeting_buddy_vector_store_routing,
        meeting_buddy_voice_agent,
        meeting_buddy_workflow_triggers,
        messages,
        models,
        organizations,
        personal_connectors,
        pricing_tiers,
        reference_data,
        responses,
        roles,
        rule_access_rights,
        rule_attachments,
        rule_operations,
        rule_statistics,
        rules,
        spaces,
        store_files,
        streamline,
        threads,
        tools,
        user_management,
        user_preferences,
        users_v2,
        vector_store_files,
        vector_stores,
        vision,
        web_scraping,
        webhooks,
        workflows,
    )
    from .client import Aitronos, AsyncAitronos
    from .connectors_data_pipeline import SyncRequestSyncMode
    from .environment import AitronosEnvironment
    from .meeting_buddy_calendar import ConnectCalendarResponse
    from .responses import (
        ChatRequestToolsItem,
        ChatRequestToolsItem_Function,
        ChatRequestToolsItem_Mcp,
        ChatRequestToolsItem_PersonalConnector,
    )
_dynamic_imports: typing.Dict[str, str] = {
    "AccessGrantListResponse": ".types",
    "AccessGrantResponse": ".types",
    "AccessItem": ".types",
    "AccessLevel": ".types",
    "AccessOverviewGrant": ".types",
    "AccessOverviewResponse": ".types",
    "AccessOverviewSlice": ".types",
    "AccessOverviewStore": ".types",
    "AccessRightGrantRequest": ".types",
    "AccessRightListResponse": ".types",
    "AccessRightResponse": ".types",
    "ActionItemListResponse": ".types",
    "ActionItemResponse": ".types",
    "ActionItemsOverviewResponse": ".types",
    "ActiveSessionSummary": ".types",
    "ActivityLogEntry": ".types",
    "ActivityLogResponse": ".types",
    "AddThreadToSpaceResponse": ".types",
    "AddToVectorStoreResponse": ".types",
    "AddVectorStoreToSpaceResponse": ".types",
    "Aitronos": ".client",
    "AitronosEnvironment": ".environment",
    "ApiKeyActionResponse": ".types",
    "ApiKeyCreateResponse": ".types",
    "ApiKeyDailyUsageResponse": ".types",
    "ApiKeyLimit": ".types",
    "ApiKeyListResponse": ".types",
    "ApiKeyResponse": ".types",
    "ApiKeyRotateResponse": ".types",
    "ApiKeyUsageDetail": ".types",
    "ApiKeyUsageSummary": ".types",
    "ApiLimits": ".types",
    "AppApiV1SchemasAssistantsAuditLogListResponse": ".types",
    "AppApiV1SchemasAuditLogV2AuditLogListResponse": ".types",
    "AppApiV1SchemasKnowledgeStoreFilesProcessingStatusResponse": ".types",
    "AppApiV1SchemasMeetingBuddyAnalyticsTopicItem": ".types",
    "AppApiV1SchemasMeetingBuddySearchTopicItem": ".types",
    "AppApiV1SchemasMeetingBuddySearchTopicListResponse": ".types",
    "AppApiV1SchemasMeetingBuddyTopicListResponse": ".types",
    "AppApiV1SchemasVectorStoreFileProcessingStatusResponse": ".types",
    "ApplyMode": ".types",
    "AssignRoleMemberResponse": ".types",
    "AssistantActiveSessionResponse": ".types",
    "AssistantListResponse": ".types",
    "AssistantListResponseAssistantsItem": ".types",
    "AssistantMbpConfigResponse": ".types",
    "AssistantResponse": ".types",
    "AssistantSelection": ".types",
    "AssistantStandardResponse": ".types",
    "AssistantSummaryResponse": ".types",
    "AsyncAitronos": ".client",
    "AttachmentCreateInline": ".types",
    "AttachmentDeleteResponse": ".types",
    "AttachmentListResponse": ".types",
    "AttachmentResponse": ".types",
    "AttachmentSummary": ".types",
    "AudioModelInfo": ".types",
    "AuditEntryResponse": ".types",
    "AuditLogEntry": ".types",
    "AuditLogResponse": ".types",
    "AuditLogSchema": ".types",
    "AuthConfigInfo": ".types",
    "AuthFieldSchema": ".types",
    "AuthModeResponse": ".types",
    "AuthSchemaResponse": ".types",
    "AuthorizationResponse": ".types",
    "AutoJoinRuleListResponse": ".types",
    "AutoJoinRuleResponse": ".types",
    "AvailableConnectorsResponse": ".types",
    "AvatarListResponse": ".types",
    "AvatarResponse": ".types",
    "BadRequestError": ".errors",
    "Base64FileUpload": ".types",
    "BatchExtractResponse": ".types",
    "BatchScrapeOptions": ".types",
    "BreakdownItem": ".types",
    "BreakdownResponse": ".types",
    "BriefingResponse": ".types",
    "BulkGrantEntry": ".types",
    "BulkOperationResponse": ".types",
    "CalendarConnectionListResponse": ".types",
    "CalendarConnectionResponse": ".types",
    "CalendarEventListResponse": ".types",
    "CalendarEventResponse": ".types",
    "CalendarSyncResponse": ".types",
    "CancelStreamResponse": ".types",
    "CapabilityMetadataResponse": ".types",
    "CategoryStatistics": ".types",
    "CategoryStatisticsResponse": ".types",
    "ChangeDetail": ".types",
    "ChangeLogListResponse": ".types",
    "ChangeLogRequest": ".types",
    "ChangeLogResponse": ".types",
    "ChangePresetResponse": ".types",
    "ChangeSchema": ".types",
    "ChatRequestToolsItem": ".responses",
    "ChatRequestToolsItem_Function": ".responses",
    "ChatRequestToolsItem_Mcp": ".responses",
    "ChatRequestToolsItem_PersonalConnector": ".responses",
    "CheckExistsResponse": ".types",
    "CheckUsernameResponse": ".types",
    "ChunkedUploadResponse": ".types",
    "ClearAllCachesResponse": ".types",
    "ClearAllCachesResponseCachesClearedValue": ".types",
    "CoachingScoreResponse": ".types",
    "CompetitorListResponse": ".types",
    "CompetitorMentionListResponse": ".types",
    "CompetitorMentionResponse": ".types",
    "CompleteInvitationResponse": ".types",
    "CompleteOAuthResponse": ".types",
    "ComponentStatus": ".types",
    "ComposioSyncResponse": ".types",
    "ComposioSyncStatusResponse": ".types",
    "CompositeMemberMapping": ".types",
    "ConfidenceBucket": ".types",
    "ConfidenceMetrics": ".types",
    "ConfidenceTrendPoint": ".types",
    "ConfigFieldDescriptor": ".types",
    "ConfigFieldDescriptorMaximum": ".types",
    "ConfigFieldDescriptorMinimum": ".types",
    "ConfigFieldType": ".types",
    "ConfigSelectOption": ".types",
    "ConflictError": ".errors",
    "ConnectCalendarOAuthResponse": ".types",
    "ConnectCalendarResponse": ".meeting_buddy_calendar",
    "ConnectionConfigOptionsResponse": ".types",
    "ConnectionInfo": ".types",
    "ConnectionTestResult": ".types",
    "ConnectionsResponse": ".types",
    "ConnectorInfo": ".types",
    "ConnectorResponse": ".types",
    "ConnectorToolsResponse": ".types",
    "ConsentRecordResponse": ".types",
    "ConsentSummary": ".types",
    "ConvertToWorkflowResponse": ".types",
    "CountryResponse": ".types",
    "CreateFlowplateKeyResponse": ".types",
    "CredentialHealthStatus": ".types",
    "CredentialTestRequest": ".types",
    "CredentialTestResult": ".types",
    "DailyApiKeyUsage": ".types",
    "DataExportActionItem": ".types",
    "DataExportConsentRecord": ".types",
    "DataExportIntelligence": ".types",
    "DataExportResponse": ".types",
    "DataExportSession": ".types",
    "DataExportTranscript": ".types",
    "DateFilter": ".types",
    "DealListResponse": ".types",
    "DealSummaryResponse": ".types",
    "DealTimelineEntry": ".types",
    "DealTimelineResponse": ".types",
    "DealTrackingResponse": ".types",
    "DecisionListResponse": ".types",
    "DecisionResponse": ".types",
    "DecisionsResponse": ".types",
    "DeleteAllThreadsResponse": ".types",
    "DeleteConnectionResponse": ".types",
    "DeleteMessageResponse": ".types",
    "DepartmentMemberResponse": ".types",
    "DepartmentMembership": ".types",
    "DepartmentResponse": ".types",
    "DepartmentTreeResponse": ".types",
    "DetachWorkflowResponse": ".types",
    "DetailedHealthCheck": ".types",
    "DeviceInformation": ".types",
    "DeviceSessionResponse": ".types",
    "DiarizeResponse": ".types",
    "DocumentExtractResponse": ".types",
    "DurationBucket": ".types",
    "DurationDistributionResponse": ".types",
    "EffectivePermissionsResponse": ".types",
    "EffectivePermissionsResponseDepartmentScope": ".types",
    "EmailValidationResponse": ".types",
    "EmotionDetectionResponse": ".types",
    "EngineType": ".types",
    "EntityType": ".types",
    "ExecutionLogEntry": ".types",
    "ExecutionLogsResponse": ".types",
    "ExecutionReturnMode": ".types",
    "ExportRequest": ".types",
    "FailedOperation": ".types",
    "FailureAnalysisResponse": ".types",
    "FailureItem": ".types",
    "FileBatchUploadResponse": ".types",
    "FileContentResponse": ".types",
    "FileListResponse": ".types",
    "FileReference": ".types",
    "FileResponse": ".types",
    "FileUploadConfigResponse": ".types",
    "FiltersAppliedSchema": ".types",
    "FlowplateKeyActionResponse": ".types",
    "ForbiddenError": ".errors",
    "FrameworkListResponse": ".types",
    "FunctionTool": ".types",
    "GitSyncResponse": ".types",
    "GitUploadResponse": ".types",
    "GoogleAuthorizeResponse": ".types",
    "GrantPathEntryResolved": ".types",
    "GrantPathEntryResponse": ".types",
    "HealthCheck": ".types",
    "HealthResponse": ".types",
    "HttpValidationError": ".types",
    "IconListResponse": ".types",
    "IconResponse": ".types",
    "ImageAnalyzeResponse": ".types",
    "ImageUploadResponse": ".types",
    "ImapConnectionResponse": ".types",
    "ImapFooterResponse": ".types",
    "InputMessage": ".types",
    "InputMessageContent": ".types",
    "IntelligenceConfigListResponse": ".types",
    "IntelligenceConfigResponse": ".types",
    "IntelligenceFeatures": ".types",
    "IntelligenceResponse": ".types",
    "InternalServerError": ".errors",
    "InvalidateLimitCacheResponse": ".types",
    "InvitationDetailsResponse": ".types",
    "InvitationResponse": ".types",
    "JobListResponse": ".types",
    "JobMetadata": ".types",
    "JobStatus": ".types",
    "JobStatusResponse": ".types",
    "JoinAllToggleResponse": ".types",
    "KnowledgeSliceListResponse": ".types",
    "KnowledgeSliceResponse": ".types",
    "KnowledgeVectorStoreCreate": ".types",
    "KnowledgeVectorStoreListResponse": ".types",
    "KnowledgeVectorStoreResponse": ".types",
    "LimitUpdateResponse": ".types",
    "LimitsSummary": ".types",
    "ListAuthConfigsResponse": ".types",
    "LiveConfigResponse": ".types",
    "LiveInteractionListResponse": ".types",
    "LiveInteractionResponse": ".types",
    "LiveMessageResponse": ".types",
    "LlmMode": ".types",
    "LoginRequest": ".types",
    "LoginResponse": ".types",
    "LoginVerificationResponse": ".types",
    "LogoutResponse": ".types",
    "ManualUploadResponse": ".types",
    "McpConfigurationListResponse": ".types",
    "McpConfigurationResponse": ".types",
    "McpServerInfo": ".types",
    "McpTool": ".types",
    "McpToolSchema": ".types",
    "McpToolSchemaAllowedTools": ".types",
    "McpToolSchemaRequireApproval": ".types",
    "MeetingTypeDistributionResponse": ".types",
    "MeetingTypeItem": ".types",
    "MemberListResponse": ".types",
    "MemberResponse": ".types",
    "MessageInput": ".types",
    "MessageInputRole": ".types",
    "MessageResponse": ".types",
    "MessageResponseRole": ".types",
    "MessagesListResponse": ".types",
    "MiniChatPosition": ".types",
    "MiniChatSettingsData": ".types",
    "MiniChatSettingsPayload": ".types",
    "MiniChatSettingsResponse": ".types",
    "ModelCompatibilityResponse": ".types",
    "ModelPricing": ".types",
    "ModelReasoningOptionsResponse": ".types",
    "ModelResponse": ".types",
    "ModelsListResponse": ".types",
    "MyAccessResponse": ".types",
    "NeuronsAnalyticsDashboardResponse": ".types",
    "NeuronsBenchmarksResponse": ".types",
    "NeuronsHeatmapResponse": ".types",
    "NeuronsOptimizationResponse": ".types",
    "NeuronsTrendsResponse": ".types",
    "NotFoundError": ".errors",
    "NotImplementedError": ".errors",
    "OAuthConfigOptionsResponse": ".types",
    "OAuthCredentialsResponse": ".types",
    "OpenNewChats": ".types",
    "OrgCalendarConnectionListResponse": ".types",
    "OrgCalendarConnectionResponse": ".types",
    "OrgSettingsResponse": ".types",
    "OrganizationBasicInfo": ".types",
    "OrganizationDomainResponse": ".types",
    "OrganizationInfo": ".types",
    "OrganizationLimits": ".types",
    "OrganizationListResponse": ".types",
    "OrganizationModelSettingsResponse": ".types",
    "OrganizationResponse": ".types",
    "OutputModeInfo": ".types",
    "OutputModesResponse": ".types",
    "OwnedResource": ".types",
    "PaginationSchema": ".types",
    "PartialContext": ".types",
    "PartialToolCall": ".types",
    "ParticipantDuration": ".types",
    "ParticipantStat": ".types",
    "ParticipantsResponse": ".types",
    "PasswordResetResponse": ".types",
    "PasswordResetVerifyResponse": ".types",
    "PasswordUpdateResponse": ".types",
    "PermissionPresetResponse": ".types",
    "PersonalConnectorTool": ".types",
    "PiiSettingsResponse": ".types",
    "PinThreadResponse": ".types",
    "PipelineProcessingDetails": ".types",
    "PipelineRecordResult": ".types",
    "PipelineRecordResultStatus": ".types",
    "PipelineSuccessResponse": ".types",
    "PresetInfo": ".types",
    "PricingTierResponse": ".types",
    "PrivacySettings": ".types",
    "ProcessingLogEntry": ".types",
    "ProcessingLogsResponse": ".types",
    "PromoteToAssistantResponse": ".types",
    "PromptModule": ".types",
    "ProviderResponse": ".types",
    "ProviderValidationResponse": ".types",
    "PublicChatHistoryMessage": ".types",
    "PublicChatHistoryResponse": ".types",
    "PublicChatResponse": ".types",
    "PublicChatStatusResponse": ".types",
    "PublicTranscriptResponse": ".types",
    "PublicTranscriptSegment": ".types",
    "QualityMetricsResponse": ".types",
    "ReasoningConfig": ".types",
    "ReasoningConfigEffort": ".types",
    "ReasoningConfigSchema": ".types",
    "ReasoningConfigSchemaEffort": ".types",
    "ReasoningConfigSchemaSummary": ".types",
    "ReasoningConfigSummary": ".types",
    "ReasoningEffortOption": ".types",
    "ReasoningLevelInfo": ".types",
    "ReasoningLevelsResponse": ".types",
    "RecentDecision": ".types",
    "RecordingInfoResponse": ".types",
    "RefreshFlowplateKeyResponse": ".types",
    "RefreshTokenResponse": ".types",
    "RegenerateEmailResponse": ".types",
    "RegisterResponse": ".types",
    "RemoveUserRequest": ".types",
    "RenameConnectionResponse": ".types",
    "ResendCodeResponse": ".types",
    "ResetToNewChat": ".types",
    "ResolvedAccessResponse": ".types",
    "RetentionPolicyResponse": ".types",
    "RevenueIntelligenceResponse": ".types",
    "RoleInfo": ".types",
    "RoleMemberResponse": ".types",
    "RoleMembersListResponse": ".types",
    "RoleResponse": ".types",
    "RoleResponsePermissions": ".types",
    "RoleTemplateResponse": ".types",
    "RuleCategory": ".types",
    "RuleDetailResponse": ".types",
    "RuleListPaginatedResponse": ".types",
    "RuleListPaginatedResponseFiltersValue": ".types",
    "RuleListResponse": ".types",
    "RuleScope": ".types",
    "RuleScopeApi": ".types",
    "RuleSummary": ".types",
    "RuleType": ".types",
    "ScrapeOptions": ".types",
    "ScrapeResponse": ".types",
    "SearchFilters": ".types",
    "SearchResponse": ".types",
    "SearchResult": ".types",
    "SentimentDataPoint": ".types",
    "SentimentOverall": ".types",
    "SentimentTrendsResponse": ".types",
    "SessionChatHistoryResponse": ".types",
    "SessionChatMessage": ".types",
    "SessionConsentResponse": ".types",
    "SessionListResponse": ".types",
    "SessionParticipantEvent": ".types",
    "SessionParticipantsResponse": ".types",
    "SessionResponse": ".types",
    "SessionSpeakerBreakdownResponse": ".types",
    "SessionSpeakerDetail": ".types",
    "SetCurrentOrganizationResponse": ".types",
    "ShareTokenCreate": ".types",
    "SharedResource": ".types",
    "SiteAnalysisResponse": ".types",
    "SliceAccessEntry": ".types",
    "SliceStoreMapping": ".types",
    "SpaceListResponse": ".types",
    "SpaceResponse": ".types",
    "SpaceThreadListResponse": ".types",
    "SpaceVectorStoreEntry": ".types",
    "SpaceVectorStoreListResponse": ".types",
    "SpeakerAnalysis": ".types",
    "SpeakerDetail": ".types",
    "SpeakerEmbeddingListResponse": ".types",
    "SpeakerEmbeddingResponse": ".types",
    "SpeakerIdentifyResponse": ".types",
    "SpeakerInfo": ".types",
    "SpeakerStat": ".types",
    "SpeakerStatsResponse": ".types",
    "SpeakersResponse": ".types",
    "StatusCount": ".types",
    "StatusInfo": ".types",
    "StatusResponse": ".types",
    "StatusSummaryResponse": ".types",
    "StorageUsageResponse": ".types",
    "StoreAccessEntry": ".types",
    "StoreFileDetailResponse": ".types",
    "StoreFileListItem": ".types",
    "StoreFileListResponse": ".types",
    "StoreFileUploadResponse": ".types",
    "StoreUsageEntry": ".types",
    "StreamlineAutomationListResponse": ".types",
    "StreamlineAutomationResponse": ".types",
    "StreamlineExecutionListResponse": ".types",
    "StreamlineExecutionResponse": ".types",
    "StreamlineGitSyncJobListResponse": ".types",
    "StreamlineGitSyncJobResponse": ".types",
    "SuccessResponseDict": ".types",
    "SuccessResponseListVectorStoreResponse": ".types",
    "SuccessResponseProcessingStatusResponse": ".types",
    "SuccessResponseVectorStoreFileListResponse": ".types",
    "SuccessResponseVectorStoreFileResponse": ".types",
    "SuccessResponseVectorStoreResponse": ".types",
    "SuccessResponseVectorStoreUsageResponse": ".types",
    "SummaryOption": ".types",
    "SummaryResponse": ".types",
    "SupportedFileCategory": ".types",
    "SyncOperation": ".types",
    "SyncOperationAction": ".types",
    "SyncRequestSyncMode": ".connectors_data_pipeline",
    "SynthesizeRequest": ".types",
    "SystemToolResponse": ".types",
    "SystemToolSchema": ".types",
    "SystemToolsListResponse": ".types",
    "TeamScoreSummary": ".types",
    "TeamSummaryResponse": ".types",
    "ThreadListResponse": ".types",
    "ThreadResponse": ".types",
    "TimezoneResponse": ".types",
    "ToggleConnectionResponse": ".types",
    "TokenValidationResponse": ".types",
    "TooManyRequestsError": ".errors",
    "ToolCapabilitiesResponse": ".types",
    "ToolConfigurationSchema": ".types",
    "ToolInfo": ".types",
    "ToolParameterResponse": ".types",
    "TopAssignee": ".types",
    "TopicResponse": ".types",
    "TopicSegmentResponse": ".types",
    "TopicsResponse": ".types",
    "TranscribeNowResponse": ".types",
    "TranscribeResponse": ".types",
    "TranscriptSegment": ".types",
    "TranscriptionCreateRequest": ".types",
    "TranscriptionOptions": ".types",
    "TranscriptionStatsResponse": ".types",
    "TrendDataPoint": ".types",
    "TrendsResponse": ".types",
    "TriggerConfigSchema": ".types",
    "UiAccessActions": ".types",
    "UiAccessPages": ".types",
    "UiAccessResponse": ".types",
    "UnauthorizedError": ".errors",
    "UnprocessableEntityError": ".errors",
    "UnsupportedFileCategory": ".types",
    "UpdateMessageResponse": ".types",
    "UpdateMessageResponseRole": ".types",
    "UpdateProfileResponse": ".types",
    "UpdateToolStatusResponse": ".types",
    "UpdateUsernameResponse": ".types",
    "UsageAnalyticsResponse": ".types",
    "UsageByEntityType": ".types",
    "UsageLimitsResponse": ".types",
    "UsageStatisticsResponse": ".types",
    "UsageSummaryResponse": ".types",
    "UserAccessEntryResponse": ".types",
    "UserBriefResponse": ".types",
    "UserContextSchema": ".types",
    "UserProfileResponse": ".types",
    "UserResponse": ".types",
    "UserV2Response": ".types",
    "UsersWithAccessResponse": ".types",
    "Utterance": ".types",
    "ValidationError": ".types",
    "ValidationErrorLocItem": ".types",
    "VectorStoreBase64UploadResponse": ".types",
    "VectorStoreFileListResponse": ".types",
    "VectorStoreFileResponse": ".types",
    "VectorStoreResponse": ".types",
    "VectorStoreUsageItem": ".types",
    "VectorStoreUsageResponse": ".types",
    "VideoMetadataResponse": ".types",
    "VideoQualityConfig": ".types",
    "VoiceAgentStatusResponse": ".types",
    "VoiceProfileListResponse": ".types",
    "VoiceProfileResponse": ".types",
    "WebhookConfig": ".types",
    "WelcomeDetailsResponse": ".types",
    "WorkflowExecutionResponse": ".types",
    "WorkflowListResponse": ".types",
    "WorkflowResponse": ".types",
    "WorkflowTriggerResponse": ".types",
    "WorkflowUpdate": ".types",
    "access_control": ".access_control",
    "admin_cache": ".admin_cache",
    "admin_connectors": ".admin_connectors",
    "analytics_api_keys": ".analytics_api_keys",
    "analytics_limits": ".analytics_limits",
    "analytics_usage": ".analytics_usage",
    "api_keys": ".api_keys",
    "assistant_mbp_configuration": ".assistant_mbp_configuration",
    "assistants": ".assistants",
    "audio": ".audio",
    "audio_services": ".audio_services",
    "audit_log_v2": ".audit_log_v2",
    "authentication": ".authentication",
    "avatars": ".avatars",
    "config": ".config",
    "connectors_data_pipeline": ".connectors_data_pipeline",
    "crew_management_admin": ".crew_management_admin",
    "crew_management_invitations": ".crew_management_invitations",
    "crew_management_members": ".crew_management_members",
    "departments": ".departments",
    "document_extraction": ".document_extraction",
    "entity_rules": ".entity_rules",
    "files": ".files",
    "flowplate_integration": ".flowplate_integration",
    "health": ".health",
    "icons": ".icons",
    "image_operations": ".image_operations",
    "knowledge": ".knowledge",
    "knowledge_connectors": ".knowledge_connectors",
    "mcp": ".mcp",
    "mcp_configurations": ".mcp_configurations",
    "meeting_buddy": ".meeting_buddy",
    "meeting_buddy_analytics": ".meeting_buddy_analytics",
    "meeting_buddy_auto_join": ".meeting_buddy_auto_join",
    "meeting_buddy_calendar": ".meeting_buddy_calendar",
    "meeting_buddy_compliance": ".meeting_buddy_compliance",
    "meeting_buddy_intelligence": ".meeting_buddy_intelligence",
    "meeting_buddy_intelligence_config": ".meeting_buddy_intelligence_config",
    "meeting_buddy_internal": ".meeting_buddy_internal",
    "meeting_buddy_knowledge": ".meeting_buddy_knowledge",
    "meeting_buddy_live_intelligence": ".meeting_buddy_live_intelligence",
    "meeting_buddy_note_taker": ".meeting_buddy_note_taker",
    "meeting_buddy_public": ".meeting_buddy_public",
    "meeting_buddy_revenue_intelligence": ".meeting_buddy_revenue_intelligence",
    "meeting_buddy_settings": ".meeting_buddy_settings",
    "meeting_buddy_streaming": ".meeting_buddy_streaming",
    "meeting_buddy_vector_store_routing": ".meeting_buddy_vector_store_routing",
    "meeting_buddy_voice_agent": ".meeting_buddy_voice_agent",
    "meeting_buddy_workflow_triggers": ".meeting_buddy_workflow_triggers",
    "messages": ".messages",
    "models": ".models",
    "organizations": ".organizations",
    "personal_connectors": ".personal_connectors",
    "pricing_tiers": ".pricing_tiers",
    "reference_data": ".reference_data",
    "responses": ".responses",
    "roles": ".roles",
    "rule_access_rights": ".rule_access_rights",
    "rule_attachments": ".rule_attachments",
    "rule_operations": ".rule_operations",
    "rule_statistics": ".rule_statistics",
    "rules": ".rules",
    "spaces": ".spaces",
    "store_files": ".store_files",
    "streamline": ".streamline",
    "threads": ".threads",
    "tools": ".tools",
    "user_management": ".user_management",
    "user_preferences": ".user_preferences",
    "users_v2": ".users_v2",
    "vector_store_files": ".vector_store_files",
    "vector_stores": ".vector_stores",
    "vision": ".vision",
    "web_scraping": ".web_scraping",
    "webhooks": ".webhooks",
    "workflows": ".workflows",
}


def __getattr__(attr_name: str) -> typing.Any:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(f"No {attr_name} found in _dynamic_imports for module name -> {__name__}")
    try:
        module = import_module(module_name, __package__)
        if module_name == f".{attr_name}":
            return module
        else:
            return getattr(module, attr_name)
    except ImportError as e:
        raise ImportError(f"Failed to import {attr_name} from {module_name}: {e}") from e
    except AttributeError as e:
        raise AttributeError(f"Failed to get {attr_name} from {module_name}: {e}") from e


def __dir__():
    lazy_attrs = list(_dynamic_imports.keys())
    return sorted(lazy_attrs)


__all__ = [
    "AccessGrantListResponse",
    "AccessGrantResponse",
    "AccessItem",
    "AccessLevel",
    "AccessOverviewGrant",
    "AccessOverviewResponse",
    "AccessOverviewSlice",
    "AccessOverviewStore",
    "AccessRightGrantRequest",
    "AccessRightListResponse",
    "AccessRightResponse",
    "ActionItemListResponse",
    "ActionItemResponse",
    "ActionItemsOverviewResponse",
    "ActiveSessionSummary",
    "ActivityLogEntry",
    "ActivityLogResponse",
    "AddThreadToSpaceResponse",
    "AddToVectorStoreResponse",
    "AddVectorStoreToSpaceResponse",
    "Aitronos",
    "AitronosEnvironment",
    "ApiKeyActionResponse",
    "ApiKeyCreateResponse",
    "ApiKeyDailyUsageResponse",
    "ApiKeyLimit",
    "ApiKeyListResponse",
    "ApiKeyResponse",
    "ApiKeyRotateResponse",
    "ApiKeyUsageDetail",
    "ApiKeyUsageSummary",
    "ApiLimits",
    "AppApiV1SchemasAssistantsAuditLogListResponse",
    "AppApiV1SchemasAuditLogV2AuditLogListResponse",
    "AppApiV1SchemasKnowledgeStoreFilesProcessingStatusResponse",
    "AppApiV1SchemasMeetingBuddyAnalyticsTopicItem",
    "AppApiV1SchemasMeetingBuddySearchTopicItem",
    "AppApiV1SchemasMeetingBuddySearchTopicListResponse",
    "AppApiV1SchemasMeetingBuddyTopicListResponse",
    "AppApiV1SchemasVectorStoreFileProcessingStatusResponse",
    "ApplyMode",
    "AssignRoleMemberResponse",
    "AssistantActiveSessionResponse",
    "AssistantListResponse",
    "AssistantListResponseAssistantsItem",
    "AssistantMbpConfigResponse",
    "AssistantResponse",
    "AssistantSelection",
    "AssistantStandardResponse",
    "AssistantSummaryResponse",
    "AsyncAitronos",
    "AttachmentCreateInline",
    "AttachmentDeleteResponse",
    "AttachmentListResponse",
    "AttachmentResponse",
    "AttachmentSummary",
    "AudioModelInfo",
    "AuditEntryResponse",
    "AuditLogEntry",
    "AuditLogResponse",
    "AuditLogSchema",
    "AuthConfigInfo",
    "AuthFieldSchema",
    "AuthModeResponse",
    "AuthSchemaResponse",
    "AuthorizationResponse",
    "AutoJoinRuleListResponse",
    "AutoJoinRuleResponse",
    "AvailableConnectorsResponse",
    "AvatarListResponse",
    "AvatarResponse",
    "BadRequestError",
    "Base64FileUpload",
    "BatchExtractResponse",
    "BatchScrapeOptions",
    "BreakdownItem",
    "BreakdownResponse",
    "BriefingResponse",
    "BulkGrantEntry",
    "BulkOperationResponse",
    "CalendarConnectionListResponse",
    "CalendarConnectionResponse",
    "CalendarEventListResponse",
    "CalendarEventResponse",
    "CalendarSyncResponse",
    "CancelStreamResponse",
    "CapabilityMetadataResponse",
    "CategoryStatistics",
    "CategoryStatisticsResponse",
    "ChangeDetail",
    "ChangeLogListResponse",
    "ChangeLogRequest",
    "ChangeLogResponse",
    "ChangePresetResponse",
    "ChangeSchema",
    "ChatRequestToolsItem",
    "ChatRequestToolsItem_Function",
    "ChatRequestToolsItem_Mcp",
    "ChatRequestToolsItem_PersonalConnector",
    "CheckExistsResponse",
    "CheckUsernameResponse",
    "ChunkedUploadResponse",
    "ClearAllCachesResponse",
    "ClearAllCachesResponseCachesClearedValue",
    "CoachingScoreResponse",
    "CompetitorListResponse",
    "CompetitorMentionListResponse",
    "CompetitorMentionResponse",
    "CompleteInvitationResponse",
    "CompleteOAuthResponse",
    "ComponentStatus",
    "ComposioSyncResponse",
    "ComposioSyncStatusResponse",
    "CompositeMemberMapping",
    "ConfidenceBucket",
    "ConfidenceMetrics",
    "ConfidenceTrendPoint",
    "ConfigFieldDescriptor",
    "ConfigFieldDescriptorMaximum",
    "ConfigFieldDescriptorMinimum",
    "ConfigFieldType",
    "ConfigSelectOption",
    "ConflictError",
    "ConnectCalendarOAuthResponse",
    "ConnectCalendarResponse",
    "ConnectionConfigOptionsResponse",
    "ConnectionInfo",
    "ConnectionTestResult",
    "ConnectionsResponse",
    "ConnectorInfo",
    "ConnectorResponse",
    "ConnectorToolsResponse",
    "ConsentRecordResponse",
    "ConsentSummary",
    "ConvertToWorkflowResponse",
    "CountryResponse",
    "CreateFlowplateKeyResponse",
    "CredentialHealthStatus",
    "CredentialTestRequest",
    "CredentialTestResult",
    "DailyApiKeyUsage",
    "DataExportActionItem",
    "DataExportConsentRecord",
    "DataExportIntelligence",
    "DataExportResponse",
    "DataExportSession",
    "DataExportTranscript",
    "DateFilter",
    "DealListResponse",
    "DealSummaryResponse",
    "DealTimelineEntry",
    "DealTimelineResponse",
    "DealTrackingResponse",
    "DecisionListResponse",
    "DecisionResponse",
    "DecisionsResponse",
    "DeleteAllThreadsResponse",
    "DeleteConnectionResponse",
    "DeleteMessageResponse",
    "DepartmentMemberResponse",
    "DepartmentMembership",
    "DepartmentResponse",
    "DepartmentTreeResponse",
    "DetachWorkflowResponse",
    "DetailedHealthCheck",
    "DeviceInformation",
    "DeviceSessionResponse",
    "DiarizeResponse",
    "DocumentExtractResponse",
    "DurationBucket",
    "DurationDistributionResponse",
    "EffectivePermissionsResponse",
    "EffectivePermissionsResponseDepartmentScope",
    "EmailValidationResponse",
    "EmotionDetectionResponse",
    "EngineType",
    "EntityType",
    "ExecutionLogEntry",
    "ExecutionLogsResponse",
    "ExecutionReturnMode",
    "ExportRequest",
    "FailedOperation",
    "FailureAnalysisResponse",
    "FailureItem",
    "FileBatchUploadResponse",
    "FileContentResponse",
    "FileListResponse",
    "FileReference",
    "FileResponse",
    "FileUploadConfigResponse",
    "FiltersAppliedSchema",
    "FlowplateKeyActionResponse",
    "ForbiddenError",
    "FrameworkListResponse",
    "FunctionTool",
    "GitSyncResponse",
    "GitUploadResponse",
    "GoogleAuthorizeResponse",
    "GrantPathEntryResolved",
    "GrantPathEntryResponse",
    "HealthCheck",
    "HealthResponse",
    "HttpValidationError",
    "IconListResponse",
    "IconResponse",
    "ImageAnalyzeResponse",
    "ImageUploadResponse",
    "ImapConnectionResponse",
    "ImapFooterResponse",
    "InputMessage",
    "InputMessageContent",
    "IntelligenceConfigListResponse",
    "IntelligenceConfigResponse",
    "IntelligenceFeatures",
    "IntelligenceResponse",
    "InternalServerError",
    "InvalidateLimitCacheResponse",
    "InvitationDetailsResponse",
    "InvitationResponse",
    "JobListResponse",
    "JobMetadata",
    "JobStatus",
    "JobStatusResponse",
    "JoinAllToggleResponse",
    "KnowledgeSliceListResponse",
    "KnowledgeSliceResponse",
    "KnowledgeVectorStoreCreate",
    "KnowledgeVectorStoreListResponse",
    "KnowledgeVectorStoreResponse",
    "LimitUpdateResponse",
    "LimitsSummary",
    "ListAuthConfigsResponse",
    "LiveConfigResponse",
    "LiveInteractionListResponse",
    "LiveInteractionResponse",
    "LiveMessageResponse",
    "LlmMode",
    "LoginRequest",
    "LoginResponse",
    "LoginVerificationResponse",
    "LogoutResponse",
    "ManualUploadResponse",
    "McpConfigurationListResponse",
    "McpConfigurationResponse",
    "McpServerInfo",
    "McpTool",
    "McpToolSchema",
    "McpToolSchemaAllowedTools",
    "McpToolSchemaRequireApproval",
    "MeetingTypeDistributionResponse",
    "MeetingTypeItem",
    "MemberListResponse",
    "MemberResponse",
    "MessageInput",
    "MessageInputRole",
    "MessageResponse",
    "MessageResponseRole",
    "MessagesListResponse",
    "MiniChatPosition",
    "MiniChatSettingsData",
    "MiniChatSettingsPayload",
    "MiniChatSettingsResponse",
    "ModelCompatibilityResponse",
    "ModelPricing",
    "ModelReasoningOptionsResponse",
    "ModelResponse",
    "ModelsListResponse",
    "MyAccessResponse",
    "NeuronsAnalyticsDashboardResponse",
    "NeuronsBenchmarksResponse",
    "NeuronsHeatmapResponse",
    "NeuronsOptimizationResponse",
    "NeuronsTrendsResponse",
    "NotFoundError",
    "NotImplementedError",
    "OAuthConfigOptionsResponse",
    "OAuthCredentialsResponse",
    "OpenNewChats",
    "OrgCalendarConnectionListResponse",
    "OrgCalendarConnectionResponse",
    "OrgSettingsResponse",
    "OrganizationBasicInfo",
    "OrganizationDomainResponse",
    "OrganizationInfo",
    "OrganizationLimits",
    "OrganizationListResponse",
    "OrganizationModelSettingsResponse",
    "OrganizationResponse",
    "OutputModeInfo",
    "OutputModesResponse",
    "OwnedResource",
    "PaginationSchema",
    "PartialContext",
    "PartialToolCall",
    "ParticipantDuration",
    "ParticipantStat",
    "ParticipantsResponse",
    "PasswordResetResponse",
    "PasswordResetVerifyResponse",
    "PasswordUpdateResponse",
    "PermissionPresetResponse",
    "PersonalConnectorTool",
    "PiiSettingsResponse",
    "PinThreadResponse",
    "PipelineProcessingDetails",
    "PipelineRecordResult",
    "PipelineRecordResultStatus",
    "PipelineSuccessResponse",
    "PresetInfo",
    "PricingTierResponse",
    "PrivacySettings",
    "ProcessingLogEntry",
    "ProcessingLogsResponse",
    "PromoteToAssistantResponse",
    "PromptModule",
    "ProviderResponse",
    "ProviderValidationResponse",
    "PublicChatHistoryMessage",
    "PublicChatHistoryResponse",
    "PublicChatResponse",
    "PublicChatStatusResponse",
    "PublicTranscriptResponse",
    "PublicTranscriptSegment",
    "QualityMetricsResponse",
    "ReasoningConfig",
    "ReasoningConfigEffort",
    "ReasoningConfigSchema",
    "ReasoningConfigSchemaEffort",
    "ReasoningConfigSchemaSummary",
    "ReasoningConfigSummary",
    "ReasoningEffortOption",
    "ReasoningLevelInfo",
    "ReasoningLevelsResponse",
    "RecentDecision",
    "RecordingInfoResponse",
    "RefreshFlowplateKeyResponse",
    "RefreshTokenResponse",
    "RegenerateEmailResponse",
    "RegisterResponse",
    "RemoveUserRequest",
    "RenameConnectionResponse",
    "ResendCodeResponse",
    "ResetToNewChat",
    "ResolvedAccessResponse",
    "RetentionPolicyResponse",
    "RevenueIntelligenceResponse",
    "RoleInfo",
    "RoleMemberResponse",
    "RoleMembersListResponse",
    "RoleResponse",
    "RoleResponsePermissions",
    "RoleTemplateResponse",
    "RuleCategory",
    "RuleDetailResponse",
    "RuleListPaginatedResponse",
    "RuleListPaginatedResponseFiltersValue",
    "RuleListResponse",
    "RuleScope",
    "RuleScopeApi",
    "RuleSummary",
    "RuleType",
    "ScrapeOptions",
    "ScrapeResponse",
    "SearchFilters",
    "SearchResponse",
    "SearchResult",
    "SentimentDataPoint",
    "SentimentOverall",
    "SentimentTrendsResponse",
    "SessionChatHistoryResponse",
    "SessionChatMessage",
    "SessionConsentResponse",
    "SessionListResponse",
    "SessionParticipantEvent",
    "SessionParticipantsResponse",
    "SessionResponse",
    "SessionSpeakerBreakdownResponse",
    "SessionSpeakerDetail",
    "SetCurrentOrganizationResponse",
    "ShareTokenCreate",
    "SharedResource",
    "SiteAnalysisResponse",
    "SliceAccessEntry",
    "SliceStoreMapping",
    "SpaceListResponse",
    "SpaceResponse",
    "SpaceThreadListResponse",
    "SpaceVectorStoreEntry",
    "SpaceVectorStoreListResponse",
    "SpeakerAnalysis",
    "SpeakerDetail",
    "SpeakerEmbeddingListResponse",
    "SpeakerEmbeddingResponse",
    "SpeakerIdentifyResponse",
    "SpeakerInfo",
    "SpeakerStat",
    "SpeakerStatsResponse",
    "SpeakersResponse",
    "StatusCount",
    "StatusInfo",
    "StatusResponse",
    "StatusSummaryResponse",
    "StorageUsageResponse",
    "StoreAccessEntry",
    "StoreFileDetailResponse",
    "StoreFileListItem",
    "StoreFileListResponse",
    "StoreFileUploadResponse",
    "StoreUsageEntry",
    "StreamlineAutomationListResponse",
    "StreamlineAutomationResponse",
    "StreamlineExecutionListResponse",
    "StreamlineExecutionResponse",
    "StreamlineGitSyncJobListResponse",
    "StreamlineGitSyncJobResponse",
    "SuccessResponseDict",
    "SuccessResponseListVectorStoreResponse",
    "SuccessResponseProcessingStatusResponse",
    "SuccessResponseVectorStoreFileListResponse",
    "SuccessResponseVectorStoreFileResponse",
    "SuccessResponseVectorStoreResponse",
    "SuccessResponseVectorStoreUsageResponse",
    "SummaryOption",
    "SummaryResponse",
    "SupportedFileCategory",
    "SyncOperation",
    "SyncOperationAction",
    "SyncRequestSyncMode",
    "SynthesizeRequest",
    "SystemToolResponse",
    "SystemToolSchema",
    "SystemToolsListResponse",
    "TeamScoreSummary",
    "TeamSummaryResponse",
    "ThreadListResponse",
    "ThreadResponse",
    "TimezoneResponse",
    "ToggleConnectionResponse",
    "TokenValidationResponse",
    "TooManyRequestsError",
    "ToolCapabilitiesResponse",
    "ToolConfigurationSchema",
    "ToolInfo",
    "ToolParameterResponse",
    "TopAssignee",
    "TopicResponse",
    "TopicSegmentResponse",
    "TopicsResponse",
    "TranscribeNowResponse",
    "TranscribeResponse",
    "TranscriptSegment",
    "TranscriptionCreateRequest",
    "TranscriptionOptions",
    "TranscriptionStatsResponse",
    "TrendDataPoint",
    "TrendsResponse",
    "TriggerConfigSchema",
    "UiAccessActions",
    "UiAccessPages",
    "UiAccessResponse",
    "UnauthorizedError",
    "UnprocessableEntityError",
    "UnsupportedFileCategory",
    "UpdateMessageResponse",
    "UpdateMessageResponseRole",
    "UpdateProfileResponse",
    "UpdateToolStatusResponse",
    "UpdateUsernameResponse",
    "UsageAnalyticsResponse",
    "UsageByEntityType",
    "UsageLimitsResponse",
    "UsageStatisticsResponse",
    "UsageSummaryResponse",
    "UserAccessEntryResponse",
    "UserBriefResponse",
    "UserContextSchema",
    "UserProfileResponse",
    "UserResponse",
    "UserV2Response",
    "UsersWithAccessResponse",
    "Utterance",
    "ValidationError",
    "ValidationErrorLocItem",
    "VectorStoreBase64UploadResponse",
    "VectorStoreFileListResponse",
    "VectorStoreFileResponse",
    "VectorStoreResponse",
    "VectorStoreUsageItem",
    "VectorStoreUsageResponse",
    "VideoMetadataResponse",
    "VideoQualityConfig",
    "VoiceAgentStatusResponse",
    "VoiceProfileListResponse",
    "VoiceProfileResponse",
    "WebhookConfig",
    "WelcomeDetailsResponse",
    "WorkflowExecutionResponse",
    "WorkflowListResponse",
    "WorkflowResponse",
    "WorkflowTriggerResponse",
    "WorkflowUpdate",
    "access_control",
    "admin_cache",
    "admin_connectors",
    "analytics_api_keys",
    "analytics_limits",
    "analytics_usage",
    "api_keys",
    "assistant_mbp_configuration",
    "assistants",
    "audio",
    "audio_services",
    "audit_log_v2",
    "authentication",
    "avatars",
    "config",
    "connectors_data_pipeline",
    "crew_management_admin",
    "crew_management_invitations",
    "crew_management_members",
    "departments",
    "document_extraction",
    "entity_rules",
    "files",
    "flowplate_integration",
    "health",
    "icons",
    "image_operations",
    "knowledge",
    "knowledge_connectors",
    "mcp",
    "mcp_configurations",
    "meeting_buddy",
    "meeting_buddy_analytics",
    "meeting_buddy_auto_join",
    "meeting_buddy_calendar",
    "meeting_buddy_compliance",
    "meeting_buddy_intelligence",
    "meeting_buddy_intelligence_config",
    "meeting_buddy_internal",
    "meeting_buddy_knowledge",
    "meeting_buddy_live_intelligence",
    "meeting_buddy_note_taker",
    "meeting_buddy_public",
    "meeting_buddy_revenue_intelligence",
    "meeting_buddy_settings",
    "meeting_buddy_streaming",
    "meeting_buddy_vector_store_routing",
    "meeting_buddy_voice_agent",
    "meeting_buddy_workflow_triggers",
    "messages",
    "models",
    "organizations",
    "personal_connectors",
    "pricing_tiers",
    "reference_data",
    "responses",
    "roles",
    "rule_access_rights",
    "rule_attachments",
    "rule_operations",
    "rule_statistics",
    "rules",
    "spaces",
    "store_files",
    "streamline",
    "threads",
    "tools",
    "user_management",
    "user_preferences",
    "users_v2",
    "vector_store_files",
    "vector_stores",
    "vision",
    "web_scraping",
    "webhooks",
    "workflows",
]



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class AuditEntryResponse(UniversalBaseModel):
    """
    Single audit entry response.
    """

    id: str
    entity_type: str
    entity_id: str
    entity_name: typing.Optional[str] = None
    action_type: str
    actor_id: str
    actor_name: str
    actor_email: str
    target_id: typing.Optional[str] = None
    target_name: typing.Optional[str] = None
    previous_value: typing.Optional[str] = None
    new_value: typing.Optional[str] = None
    metadata: typing.Optional[typing.Dict[str, typing.Any]] = None
    organization_id: str
    department_id: typing.Optional[str] = None
    created_at: typing.Optional[dt.datetime] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class AccessGrantResponse(UniversalBaseModel):
    """
    Schema for access grant response.
    """

    id: str
    entity_type: str
    entity_id: str
    grantee_type: str
    grantee_id: str
    grantee_name: typing.Optional[str] = None
    grantee_email: typing.Optional[str] = None
    access_level: str
    granted_by: str
    granted_by_name: typing.Optional[str] = None
    organization_id: str
    created_at: dt.datetime
    updated_at: dt.datetime

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

from ..core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ..core.request_options import RequestOptions
from ..types.add_thread_to_space_response import AddThreadToSpaceResponse
from ..types.add_vector_store_to_space_response import AddVectorStoreToSpaceResponse
from ..types.space_list_response import SpaceListResponse
from ..types.space_response import SpaceResponse
from ..types.space_thread_list_response import SpaceThreadListResponse
from ..types.space_vector_store_list_response import SpaceVectorStoreListResponse
from .raw_client import AsyncRawSpacesClient, RawSpacesClient

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class SpacesClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._raw_client = RawSpacesClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> RawSpacesClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        RawSpacesClient
        """
        return self._raw_client

    def list_spaces(
        self,
        *,
        organization_id: str,
        limit: typing.Optional[int] = None,
        cursor: typing.Optional[str] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> SpaceListResponse:
        """
        List all spaces user has access to in an organization

        Parameters
        ----------
        organization_id : str
            Organization ID to filter by

        limit : typing.Optional[int]
            Maximum number of results

        cursor : typing.Optional[str]
            Pagination cursor

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        SpaceListResponse
            Successful Response

        Examples
        --------
        from aitronos import Aitronos

        client = Aitronos(
            api_key="YOUR_API_KEY",
            token="YOUR_TOKEN",
        )
        client.spaces.list_spaces(
            organization_id="organization_id",
        )
        """
        _response = self._raw_client.list_spaces(
            organization_id=organization_id, limit=limit, cursor=cursor, request_options=request_options
        )
        return _response.data

    def create_space(
        self,
        *,
        organization_id: str,
        name: str,
        description: typing.Optional[str] = OMIT,
        access_mode: typing.Optional[str] = OMIT,
        access_users: typing.Optional[typing.Sequence[str]] = OMIT,
        access_departments: typing.Optional[typing.Sequence[str]] = OMIT,
        editable_by_users: typing.Optional[typing.Sequence[str]] = OMIT,
        editable_by_roles: typing.Optional[typing.Sequence[str]] = OMIT,
        visible_to_roles: typing.Optional[typing.Sequence[str]] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> SpaceResponse:
        """
        Create a new space with auto-linked vector store for memory management

        Parameters
        ----------
        organization_id : str
            Organization ID

        name : str
            Space name

        description : typing.Optional[str]
            Optional space description

        access_mode : typing.Optional[str]
            Access mode: private, organization, or public

        access_users : typing.Optional[typing.Sequence[str]]
            User IDs with view access

        access_departments : typing.Optional[typing.Sequence[str]]
            Department IDs with view access

        editable_by_users : typing.Optional[typing.Sequence[str]]
            User IDs with edit access (supports wildcard '*')

        editable_by_roles : typing.Optional[typing.Sequence[str]]
            Role IDs with edit access

        visible_to_roles : typing.Optional[typing.Sequence[str]]
            Role IDs with view access

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        SpaceResponse
            Successful Response

        Examples
        --------
        from aitronos import Aitronos

        client = Aitronos(
            api_key="YOUR_API_KEY",
            token="YOUR_TOKEN",
        )
        client.spaces.create_space(
            organization_id="org_a1b2c3d4e5f6a1b2c3d4e5f6a1b2c3d4",
            name="Project Alpha",
            description="Shared space for Project Alpha team",
            access_mode="organization",
        )
        """
        _response = self._raw_client.create_space(
            organization_id=organization_id,
            name=name,
            description=description,
            access_mode=access_mode,
            access_users=access_users,
            access_departments=access_departments,
            editable_by_users=editable_by_users,
            editable_by_roles=editable_by_roles,
            visible_to_roles=visible_to_roles,
            request_options=request_options,
        )
        return _response.data

    def get_space(
        self, space_id: str, *, organization_id: str, request_options: typing.Optional[RequestOptions] = None
    ) -> SpaceResponse:
        """
        Retrieve space details by ID with access validation

        Parameters
        ----------
        space_id : str
            Space ID

        organization_id : str
            Organization ID

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        SpaceResponse
            Successful Response

        Examples
        --------
        from aitronos import Aitronos

        client = Aitronos(
            api_key="YOUR_API_KEY",
            token="YOUR_TOKEN",
        )
        client.spaces.get_space(
            space_id="space_id",
            organization_id="organization_id",
        )
        """
        _response = self._raw_client.get_space(
            space_id, organization_id=organization_id, request_options=request_options
        )
        return _response.data

    def delete_space(
        self, space_id: str, *, organization_id: str, request_options: typing.Optional[RequestOptions] = None
    ) -> None:
        """
        Soft delete space (requires owner access)

        Parameters
        ----------
        space_id : str
            Space ID

        organization_id : str
            Organization ID

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        None

        Examples
        --------
        from aitronos import Aitronos

        client = Aitronos(
            api_key="YOUR_API_KEY",
            token="YOUR_TOKEN",
        )
        client.spaces.delete_space(
            space_id="space_id",
            organization_id="organization_id",
        )
        """
        _response = self._raw_client.delete_space(
            space_id, organization_id=organization_id, request_options=request_options
        )
        return _response.data

    def update_space(
        self,
        space_id: str,
        *,
        organization_id: str,
        name: typing.Optional[str] = OMIT,
        description: typing.Optional[str] = OMIT,
        access_mode: typing.Optional[str] = OMIT,
        access_users: typing.Optional[typing.Sequence[str]] = OMIT,
        access_departments: typing.Optional[typing.Sequence[str]] = OMIT,
        editable_by_users: typing.Optional[typing.Sequence[str]] = OMIT,
        editable_by_roles: typing.Optional[typing.Sequence[str]] = OMIT,
        visible_to_roles: typing.Optional[typing.Sequence[str]] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> SpaceResponse:
        """
        Update space properties with access validation

        Parameters
        ----------
        space_id : str
            Space ID

        organization_id : str
            Organization ID

        name : typing.Optional[str]
            New space name

        description : typing.Optional[str]
            New space description

        access_mode : typing.Optional[str]
            New access mode

        access_users : typing.Optional[typing.Sequence[str]]
            New access users list

        access_departments : typing.Optional[typing.Sequence[str]]
            New access departments list

        editable_by_users : typing.Optional[typing.Sequence[str]]
            New editable users list

        editable_by_roles : typing.Optional[typing.Sequence[str]]
            New editable roles list

        visible_to_roles : typing.Optional[typing.Sequence[str]]
            New visible roles list

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        SpaceResponse
            Successful Response

        Examples
        --------
        from aitronos import Aitronos

        client = Aitronos(
            api_key="YOUR_API_KEY",
            token="YOUR_TOKEN",
        )
        client.spaces.update_space(
            space_id="space_id",
            organization_id="organization_id",
            name="Updated Space Name",
            description="Updated description",
            access_mode="private",
        )
        """
        _response = self._raw_client.update_space(
            space_id,
            organization_id=organization_id,
            name=name,
            description=description,
            access_mode=access_mode,
            access_users=access_users,
            access_departments=access_departments,
            editable_by_users=editable_by_users,
            editable_by_roles=editable_by_roles,
            visible_to_roles=visible_to_roles,
            request_options=request_options,
        )
        return _response.data

    def add_thread_to_space(
        self,
        space_id: str,
        thread_id: str,
        *,
        organization_id: str,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AddThreadToSpaceResponse:
        """
        Associate a thread with a space (requires edit access)

        Parameters
        ----------
        space_id : str
            Space ID

        thread_id : str
            Thread ID

        organization_id : str
            Organization ID

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AddThreadToSpaceResponse
            Successful Response

        Examples
        --------
        from aitronos import Aitronos

        client = Aitronos(
            api_key="YOUR_API_KEY",
            token="YOUR_TOKEN",
        )
        client.spaces.add_thread_to_space(
            space_id="space_id",
            thread_id="thread_id",
            organization_id="organization_id",
        )
        """
        _response = self._raw_client.add_thread_to_space(
            space_id, thread_id, organization_id=organization_id, request_options=request_options
        )
        return _response.data

    def remove_thread_from_space(
        self,
        space_id: str,
        thread_id: str,
        *,
        organization_id: str,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> None:
        """
        Remove thread from space and cleanup vectors (requires edit access)

        Parameters
        ----------
        space_id : str
            Space ID

        thread_id : str
            Thread ID

        organization_id : str
            Organization ID

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        None

        Examples
        --------
        from aitronos import Aitronos

        client = Aitronos(
            api_key="YOUR_API_KEY",
            token="YOUR_TOKEN",
        )
        client.spaces.remove_thread_from_space(
            space_id="space_id",
            thread_id="thread_id",
            organization_id="organization_id",
        )
        """
        _response = self._raw_client.remove_thread_from_space(
            space_id, thread_id, organization_id=organization_id, request_options=request_options
        )
        return _response.data

    def list_space_threads(
        self,
        space_id: str,
        *,
        organization_id: str,
        limit: typing.Optional[int] = None,
        cursor: typing.Optional[str] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> SpaceThreadListResponse:
        """
        List all threads associated with a space (requires view access)

        Parameters
        ----------
        space_id : str
            Space ID

        organization_id : str
            Organization ID

        limit : typing.Optional[int]
            Maximum number of threads to return

        cursor : typing.Optional[str]
            Pagination cursor from previous response

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        SpaceThreadListResponse
            Successful Response

        Examples
        --------
        from aitronos import Aitronos

        client = Aitronos(
            api_key="YOUR_API_KEY",
            token="YOUR_TOKEN",
        )
        client.spaces.list_space_threads(
            space_id="space_id",
            organization_id="organization_id",
        )
        """
        _response = self._raw_client.list_space_threads(
            space_id, organization_id=organization_id, limit=limit, cursor=cursor, request_options=request_options
        )
        return _response.data

    def add_vector_store_to_space(
        self,
        space_id: str,
        vector_store_id: str,
        *,
        organization_id: str,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AddVectorStoreToSpaceResponse:
        """
        Attach an additional external vector store to a space (requires edit access)

        Parameters
        ----------
        space_id : str
            Space ID

        vector_store_id : str
            Vector store ID

        organization_id : str
            Organization ID

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AddVectorStoreToSpaceResponse
            Successful Response

        Examples
        --------
        from aitronos import Aitronos

        client = Aitronos(
            api_key="YOUR_API_KEY",
            token="YOUR_TOKEN",
        )
        client.spaces.add_vector_store_to_space(
            space_id="space_id",
            vector_store_id="vector_store_id",
            organization_id="organization_id",
        )
        """
        _response = self._raw_client.add_vector_store_to_space(
            space_id, vector_store_id, organization_id=organization_id, request_options=request_options
        )
        return _response.data

    def remove_vector_store_from_space(
        self,
        space_id: str,
        vector_store_id: str,
        *,
        organization_id: str,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> None:
        """
        Remove an additional vector store from a space (requires edit access)

        Parameters
        ----------
        space_id : str
            Space ID

        vector_store_id : str
            Vector store ID

        organization_id : str
            Organization ID

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        None

        Examples
        --------
        from aitronos import Aitronos

        client = Aitronos(
            api_key="YOUR_API_KEY",
            token="YOUR_TOKEN",
        )
        client.spaces.remove_vector_store_from_space(
            space_id="space_id",
            vector_store_id="vector_store_id",
            organization_id="organization_id",
        )
        """
        _response = self._raw_client.remove_vector_store_from_space(
            space_id, vector_store_id, organization_id=organization_id, request_options=request_options
        )
        return _response.data

    def list_space_vector_stores(
        self, space_id: str, *, organization_id: str, request_options: typing.Optional[RequestOptions] = None
    ) -> SpaceVectorStoreListResponse:
        """
        List all additional vector stores attached to a space (requires view access)

        Parameters
        ----------
        space_id : str
            Space ID

        organization_id : str
            Organization ID

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        SpaceVectorStoreListResponse
            Successful Response

        Examples
        --------
        from aitronos import Aitronos

        client = Aitronos(
            api_key="YOUR_API_KEY",
            token="YOUR_TOKEN",
        )
        client.spaces.list_space_vector_stores(
            space_id="space_id",
            organization_id="organization_id",
        )
        """
        _response = self._raw_client.list_space_vector_stores(
            space_id, organization_id=organization_id, request_options=request_options
        )
        return _response.data


class AsyncSpacesClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._raw_client = AsyncRawSpacesClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> AsyncRawSpacesClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        AsyncRawSpacesClient
        """
        return self._raw_client

    async def list_spaces(
        self,
        *,
        organization_id: str,
        limit: typing.Optional[int] = None,
        cursor: typing.Optional[str] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> SpaceListResponse:
        """
        List all spaces user has access to in an organization

        Parameters
        ----------
        organization_id : str
            Organization ID to filter by

        limit : typing.Optional[int]
            Maximum number of results

        cursor : typing.Optional[str]
            Pagination cursor

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        SpaceListResponse
            Successful Response

        Examples
        --------
        import asyncio

        from aitronos import AsyncAitronos

        client = AsyncAitronos(
            api_key="YOUR_API_KEY",
            token="YOUR_TOKEN",
        )


        async def main() -> None:
            await client.spaces.list_spaces(
                organization_id="organization_id",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.list_spaces(
            organization_id=organization_id, limit=limit, cursor=cursor, request_options=request_options
        )
        return _response.data

    async def create_space(
        self,
        *,
        organization_id: str,
        name: str,
        description: typing.Optional[str] = OMIT,
        access_mode: typing.Optional[str] = OMIT,
        access_users: typing.Optional[typing.Sequence[str]] = OMIT,
        access_departments: typing.Optional[typing.Sequence[str]] = OMIT,
        editable_by_users: typing.Optional[typing.Sequence[str]] = OMIT,
        editable_by_roles: typing.Optional[typing.Sequence[str]] = OMIT,
        visible_to_roles: typing.Optional[typing.Sequence[str]] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> SpaceResponse:
        """
        Create a new space with auto-linked vector store for memory management

        Parameters
        ----------
        organization_id : str
            Organization ID

        name : str
            Space name

        description : typing.Optional[str]
            Optional space description

        access_mode : typing.Optional[str]
            Access mode: private, organization, or public

        access_users : typing.Optional[typing.Sequence[str]]
            User IDs with view access

        access_departments : typing.Optional[typing.Sequence[str]]
            Department IDs with view access

        editable_by_users : typing.Optional[typing.Sequence[str]]
            User IDs with edit access (supports wildcard '*')

        editable_by_roles : typing.Optional[typing.Sequence[str]]
            Role IDs with edit access

        visible_to_roles : typing.Optional[typing.Sequence[str]]
            Role IDs with view access

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        SpaceResponse
            Successful Response

        Examples
        --------
        import asyncio

        from aitronos import AsyncAitronos

        client = AsyncAitronos(
            api_key="YOUR_API_KEY",
            token="YOUR_TOKEN",
        )


        async def main() -> None:
            await client.spaces.create_space(
                organization_id="org_a1b2c3d4e5f6a1b2c3d4e5f6a1b2c3d4",
                name="Project Alpha",
                description="Shared space for Project Alpha team",
                access_mode="organization",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.create_space(
            organization_id=organization_id,
            name=name,
            description=description,
            access_mode=access_mode,
            access_users=access_users,
            access_departments=access_departments,
            editable_by_users=editable_by_users,
            editable_by_roles=editable_by_roles,
            visible_to_roles=visible_to_roles,
            request_options=request_options,
        )
        return _response.data

    async def get_space(
        self, space_id: str, *, organization_id: str, request_options: typing.Optional[RequestOptions] = None
    ) -> SpaceResponse:
        """
        Retrieve space details by ID with access validation

        Parameters
        ----------
        space_id : str
            Space ID

        organization_id : str
            Organization ID

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        SpaceResponse
            Successful Response

        Examples
        --------
        import asyncio

        from aitronos import AsyncAitronos

        client = AsyncAitronos(
            api_key="YOUR_API_KEY",
            token="YOUR_TOKEN",
        )


        async def main() -> None:
            await client.spaces.get_space(
                space_id="space_id",
                organization_id="organization_id",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.get_space(
            space_id, organization_id=organization_id, request_options=request_options
        )
        return _response.data

    async def delete_space(
        self, space_id: str, *, organization_id: str, request_options: typing.Optional[RequestOptions] = None
    ) -> None:
        """
        Soft delete space (requires owner access)

        Parameters
        ----------
        space_id : str
            Space ID

        organization_id : str
            Organization ID

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        None

        Examples
        --------
        import asyncio

        from aitronos import AsyncAitronos

        client = AsyncAitronos(
            api_key="YOUR_API_KEY",
            token="YOUR_TOKEN",
        )


        async def main() -> None:
            await client.spaces.delete_space(
                space_id="space_id",
                organization_id="organization_id",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.delete_space(
            space_id, organization_id=organization_id, request_options=request_options
        )
        return _response.data

    async def update_space(
        self,
        space_id: str,
        *,
        organization_id: str,
        name: typing.Optional[str] = OMIT,
        description: typing.Optional[str] = OMIT,
        access_mode: typing.Optional[str] = OMIT,
        access_users: typing.Optional[typing.Sequence[str]] = OMIT,
        access_departments: typing.Optional[typing.Sequence[str]] = OMIT,
        editable_by_users: typing.Optional[typing.Sequence[str]] = OMIT,
        editable_by_roles: typing.Optional[typing.Sequence[str]] = OMIT,
        visible_to_roles: typing.Optional[typing.Sequence[str]] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> SpaceResponse:
        """
        Update space properties with access validation

        Parameters
        ----------
        space_id : str
            Space ID

        organization_id : str
            Organization ID

        name : typing.Optional[str]
            New space name

        description : typing.Optional[str]
            New space description

        access_mode : typing.Optional[str]
            New access mode

        access_users : typing.Optional[typing.Sequence[str]]
            New access users list

        access_departments : typing.Optional[typing.Sequence[str]]
            New access departments list

        editable_by_users : typing.Optional[typing.Sequence[str]]
            New editable users list

        editable_by_roles : typing.Optional[typing.Sequence[str]]
            New editable roles list

        visible_to_roles : typing.Optional[typing.Sequence[str]]
            New visible roles list

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        SpaceResponse
            Successful Response

        Examples
        --------
        import asyncio

        from aitronos import AsyncAitronos

        client = AsyncAitronos(
            api_key="YOUR_API_KEY",
            token="YOUR_TOKEN",
        )


        async def main() -> None:
            await client.spaces.update_space(
                space_id="space_id",
                organization_id="organization_id",
                name="Updated Space Name",
                description="Updated description",
                access_mode="private",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.update_space(
            space_id,
            organization_id=organization_id,
            name=name,
            description=description,
            access_mode=access_mode,
            access_users=access_users,
            access_departments=access_departments,
            editable_by_users=editable_by_users,
            editable_by_roles=editable_by_roles,
            visible_to_roles=visible_to_roles,
            request_options=request_options,
        )
        return _response.data

    async def add_thread_to_space(
        self,
        space_id: str,
        thread_id: str,
        *,
        organization_id: str,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AddThreadToSpaceResponse:
        """
        Associate a thread with a space (requires edit access)

        Parameters
        ----------
        space_id : str
            Space ID

        thread_id : str
            Thread ID

        organization_id : str
            Organization ID

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AddThreadToSpaceResponse
            Successful Response

        Examples
        --------
        import asyncio

        from aitronos import AsyncAitronos

        client = AsyncAitronos(
            api_key="YOUR_API_KEY",
            token="YOUR_TOKEN",
        )


        async def main() -> None:
            await client.spaces.add_thread_to_space(
                space_id="space_id",
                thread_id="thread_id",
                organization_id="organization_id",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.add_thread_to_space(
            space_id, thread_id, organization_id=organization_id, request_options=request_options
        )
        return _response.data

    async def remove_thread_from_space(
        self,
        space_id: str,
        thread_id: str,
        *,
        organization_id: str,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> None:
        """
        Remove thread from space and cleanup vectors (requires edit access)

        Parameters
        ----------
        space_id : str
            Space ID

        thread_id : str
            Thread ID

        organization_id : str
            Organization ID

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        None

        Examples
        --------
        import asyncio

        from aitronos import AsyncAitronos

        client = AsyncAitronos(
            api_key="YOUR_API_KEY",
            token="YOUR_TOKEN",
        )


        async def main() -> None:
            await client.spaces.remove_thread_from_space(
                space_id="space_id",
                thread_id="thread_id",
                organization_id="organization_id",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.remove_thread_from_space(
            space_id, thread_id, organization_id=organization_id, request_options=request_options
        )
        return _response.data

    async def list_space_threads(
        self,
        space_id: str,
        *,
        organization_id: str,
        limit: typing.Optional[int] = None,
        cursor: typing.Optional[str] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> SpaceThreadListResponse:
        """
        List all threads associated with a space (requires view access)

        Parameters
        ----------
        space_id : str
            Space ID

        organization_id : str
            Organization ID

        limit : typing.Optional[int]
            Maximum number of threads to return

        cursor : typing.Optional[str]
            Pagination cursor from previous response

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        SpaceThreadListResponse
            Successful Response

        Examples
        --------
        import asyncio

        from aitronos import AsyncAitronos

        client = AsyncAitronos(
            api_key="YOUR_API_KEY",
            token="YOUR_TOKEN",
        )


        async def main() -> None:
            await client.spaces.list_space_threads(
                space_id="space_id",
                organization_id="organization_id",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.list_space_threads(
            space_id, organization_id=organization_id, limit=limit, cursor=cursor, request_options=request_options
        )
        return _response.data

    async def add_vector_store_to_space(
        self,
        space_id: str,
        vector_store_id: str,
        *,
        organization_id: str,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AddVectorStoreToSpaceResponse:
        """
        Attach an additional external vector store to a space (requires edit access)

        Parameters
        ----------
        space_id : str
            Space ID

        vector_store_id : str
            Vector store ID

        organization_id : str
            Organization ID

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AddVectorStoreToSpaceResponse
            Successful Response

        Examples
        --------
        import asyncio

        from aitronos import AsyncAitronos

        client = AsyncAitronos(
            api_key="YOUR_API_KEY",
            token="YOUR_TOKEN",
        )


        async def main() -> None:
            await client.spaces.add_vector_store_to_space(
                space_id="space_id",
                vector_store_id="vector_store_id",
                organization_id="organization_id",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.add_vector_store_to_space(
            space_id, vector_store_id, organization_id=organization_id, request_options=request_options
        )
        return _response.data

    async def remove_vector_store_from_space(
        self,
        space_id: str,
        vector_store_id: str,
        *,
        organization_id: str,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> None:
        """
        Remove an additional vector store from a space (requires edit access)

        Parameters
        ----------
        space_id : str
            Space ID

        vector_store_id : str
            Vector store ID

        organization_id : str
            Organization ID

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        None

        Examples
        --------
        import asyncio

        from aitronos import AsyncAitronos

        client = AsyncAitronos(
            api_key="YOUR_API_KEY",
            token="YOUR_TOKEN",
        )


        async def main() -> None:
            await client.spaces.remove_vector_store_from_space(
                space_id="space_id",
                vector_store_id="vector_store_id",
                organization_id="organization_id",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.remove_vector_store_from_space(
            space_id, vector_store_id, organization_id=organization_id, request_options=request_options
        )
        return _response.data

    async def list_space_vector_stores(
        self, space_id: str, *, organization_id: str, request_options: typing.Optional[RequestOptions] = None
    ) -> SpaceVectorStoreListResponse:
        """
        List all additional vector stores attached to a space (requires view access)

        Parameters
        ----------
        space_id : str
            Space ID

        organization_id : str
            Organization ID

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        SpaceVectorStoreListResponse
            Successful Response

        Examples
        --------
        import asyncio

        from aitronos import AsyncAitronos

        client = AsyncAitronos(
            api_key="YOUR_API_KEY",
            token="YOUR_TOKEN",
        )


        async def main() -> None:
            await client.spaces.list_space_vector_stores(
                space_id="space_id",
                organization_id="organization_id",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.list_space_vector_stores(
            space_id, organization_id=organization_id, request_options=request_options
        )
        return _response.data



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class OrganizationResponse(UniversalBaseModel):
    """
    Schema for organization response.
    """

    id: str
    name: str
    type: str
    description: typing.Optional[str] = None
    domain: typing.Optional[str] = pydantic.Field(default=None)
    """
    Primary email domain for the organization (deprecated, use domains)
    """

    domains: typing.Optional[typing.List[str]] = pydantic.Field(default=None)
    """
    Email domains for automatic member access
    """

    website: typing.Optional[str] = None
    industry: typing.Optional[str] = None
    company_size: typing.Optional[str] = None
    logo_image: typing.Optional[str] = None
    image_url: typing.Optional[str] = None
    is_active: bool
    owner_id: typing.Optional[str] = None
    api_usage_limit: float
    total_usage_limit: float
    storage_free_bytes_allowance: int
    pricing_tier_id: typing.Optional[str] = None
    created_at: dt.datetime
    updated_at: dt.datetime
    users_added_from_domains: typing.Optional[int] = pydantic.Field(default=None)
    """
    Number of users automatically added based on email domains
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

from ..core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ..core.request_options import RequestOptions
from ..types.detailed_health_check import DetailedHealthCheck
from ..types.health_check import HealthCheck
from .raw_client import AsyncRawHealthClient, RawHealthClient


class HealthClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._raw_client = RawHealthClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> RawHealthClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        RawHealthClient
        """
        return self._raw_client

    def liveness_check(self, *, request_options: typing.Optional[RequestOptions] = None) -> HealthCheck:
        """
        Simple liveness check endpoint.

        Returns a basic status indicating the application is running.
        Useful for container orchestration liveness probes.

        Parameters
        ----------
        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HealthCheck
            Successful Response

        Examples
        --------
        from aitronos import Aitronos

        client = Aitronos(
            api_key="YOUR_API_KEY",
            token="YOUR_TOKEN",
        )
        client.health.liveness_check()
        """
        _response = self._raw_client.liveness_check(request_options=request_options)
        return _response.data

    def readiness_check(self, *, request_options: typing.Optional[RequestOptions] = None) -> DetailedHealthCheck:
        """
        Detailed readiness check endpoint.

        Checks the health of all application dependencies including:
        - Database connectivity
        - Cache connectivity
        - Limit enforcement system status
        - Vector store connectivity

        Useful for container orchestration readiness probes.

        Parameters
        ----------
        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        DetailedHealthCheck
            Successful Response

        Examples
        --------
        from aitronos import Aitronos

        client = Aitronos(
            api_key="YOUR_API_KEY",
            token="YOUR_TOKEN",
        )
        client.health.readiness_check()
        """
        _response = self._raw_client.readiness_check(request_options=request_options)
        return _response.data

    def metrics(self, *, request_options: typing.Optional[RequestOptions] = None) -> None:
        """
        Expose Prometheus metrics.

        Returns metrics in Prometheus text format including:
        - transcriptions_created_total{model}: Total transcriptions created
        - synapses_consumed_total{model}: Total synapses consumed
        - synapses_consumed_per_second{model}: Current synapse consumption rate
        - pricing_lookup_latency_ms{model, source}: Pricing lookup latency histogram
        - pricing_errors_total{code}: Total pricing lookup errors

        Parameters
        ----------
        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        None

        Examples
        --------
        from aitronos import Aitronos

        client = Aitronos(
            api_key="YOUR_API_KEY",
            token="YOUR_TOKEN",
        )
        client.health.metrics()
        """
        _response = self._raw_client.metrics(request_options=request_options)
        return _response.data


class AsyncHealthClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._raw_client = AsyncRawHealthClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> AsyncRawHealthClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        AsyncRawHealthClient
        """
        return self._raw_client

    async def liveness_check(self, *, request_options: typing.Optional[RequestOptions] = None) -> HealthCheck:
        """
        Simple liveness check endpoint.

        Returns a basic status indicating the application is running.
        Useful for container orchestration liveness probes.

        Parameters
        ----------
        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HealthCheck
            Successful Response

        Examples
        --------
        import asyncio

        from aitronos import AsyncAitronos

        client = AsyncAitronos(
            api_key="YOUR_API_KEY",
            token="YOUR_TOKEN",
        )


        async def main() -> None:
            await client.health.liveness_check()


        asyncio.run(main())
        """
        _response = await self._raw_client.liveness_check(request_options=request_options)
        return _response.data

    async def readiness_check(self, *, request_options: typing.Optional[RequestOptions] = None) -> DetailedHealthCheck:
        """
        Detailed readiness check endpoint.

        Checks the health of all application dependencies including:
        - Database connectivity
        - Cache connectivity
        - Limit enforcement system status
        - Vector store connectivity

        Useful for container orchestration readiness probes.

        Parameters
        ----------
        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        DetailedHealthCheck
            Successful Response

        Examples
        --------
        import asyncio

        from aitronos import AsyncAitronos

        client = AsyncAitronos(
            api_key="YOUR_API_KEY",
            token="YOUR_TOKEN",
        )


        async def main() -> None:
            await client.health.readiness_check()


        asyncio.run(main())
        """
        _response = await self._raw_client.readiness_check(request_options=request_options)
        return _response.data

    async def metrics(self, *, request_options: typing.Optional[RequestOptions] = None) -> None:
        """
        Expose Prometheus metrics.

        Returns metrics in Prometheus text format including:
        - transcriptions_created_total{model}: Total transcriptions created
        - synapses_consumed_total{model}: Total synapses consumed
        - synapses_consumed_per_second{model}: Current synapse consumption rate
        - pricing_lookup_latency_ms{model, source}: Pricing lookup latency histogram
        - pricing_errors_total{code}: Total pricing lookup errors

        Parameters
        ----------
        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        None

        Examples
        --------
        import asyncio

        from aitronos import AsyncAitronos

        client = AsyncAitronos(
            api_key="YOUR_API_KEY",
            token="YOUR_TOKEN",
        )


        async def main() -> None:
            await client.health.metrics()


        asyncio.run(main())
        """
        _response = await self._raw_client.metrics(request_options=request_options)
        return _response.data



# This file was auto-generated by Fern from our API Definition.

import typing

from ...types.calendar_connection_response import CalendarConnectionResponse
from ...types.connect_calendar_o_auth_response import ConnectCalendarOAuthResponse

ConnectCalendarResponse = typing.Union[ConnectCalendarOAuthResponse, CalendarConnectionResponse]



# This file was auto-generated by Fern from our API Definition.

import typing

from .. import core
from ..core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ..core.request_options import RequestOptions
from ..types.image_analyze_response import ImageAnalyzeResponse
from .raw_client import AsyncRawVisionClient, RawVisionClient

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class VisionClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._raw_client = RawVisionClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> RawVisionClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        RawVisionClient
        """
        return self._raw_client

    def analyze_image(
        self,
        *,
        image_file: core.File,
        schema: str,
        organization_id: str,
        prompt: typing.Optional[str] = OMIT,
        model: typing.Optional[str] = OMIT,
        provider: typing.Optional[str] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> ImageAnalyzeResponse:
        """
        Analyze image and extract structured data using OpenAI Vision API.

            **Supported Providers:**
            - `openai`: GPT-5 Vision API (Aug 2025+)

            **Parameters:**
            - `image_file`: Image to analyze (PNG, JPEG, WebP)
            - `schema`: JSON schema defining extraction structure
            - `organization_id`: Organization ID (org_ prefixed string)
            - `prompt`: Optional custom instructions (e.g., "Focus on text in the center", "Ignore watermarks")
            - `model`: GPT-5 model to use (gpt-5 standard, gpt-5.1 latest, gpt-5-turbo fast, gpt-5-mini cost-effective)
            - `provider`: Provider to use (currently only openai)

            **Model Selection (GPT-5 Series Only):**
            - `gpt-5`: Standard model - best balance of quality and speed (~$0.03 per image)
            - `gpt-5.1`: Latest iteration (Nov 2025) - faster, customizable personalities (~$0.03 per image)
            - `gpt-5-turbo`: Optimized for speed while maintaining quality (~$0.02 per image)
            - `gpt-5-mini`: Fast and cost-effective for simple tasks (~$0.01 per image)

            **Use Cases:**
            - Extract data from photos
            - Analyze screenshots
            - Process scanned documents
            - OCR with structured output
            - Invoice/receipt processing

            **Billing:**
            - Cost: ~$0.01-0.03 per image (depends on GPT-5 variant)
            - Tracked through usage_events system

            **Response Headers:**
            - `X-Provider`: Provider that processed the request
            - `X-Model-Used`: Actual model used
            - `X-Cost-CHF`: Total cost in CHF

        Parameters
        ----------
        image_file : core.File
            See core.File for more documentation

        schema : str
            JSON schema defining extraction structure

        organization_id : str
            Organization ID (org_ prefixed string)

        prompt : typing.Optional[str]
            Optional custom instructions for analysis

        model : typing.Optional[str]
            GPT-5 model to use (gpt-5 standard, gpt-5.1 latest, gpt-5-turbo fast, gpt-5-mini cost-effective)

        provider : typing.Optional[str]
            Provider to use (currently only openai)

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ImageAnalyzeResponse
            Image analyzed successfully

        Examples
        --------
        from aitronos import Aitronos

        client = Aitronos(
            api_key="YOUR_API_KEY",
            token="YOUR_TOKEN",
        )
        client.vision.analyze_image(
            schema="schema",
            organization_id="organization_id",
        )
        """
        _response = self._raw_client.analyze_image(
            image_file=image_file,
            schema=schema,
            organization_id=organization_id,
            prompt=prompt,
            model=model,
            provider=provider,
            request_options=request_options,
        )
        return _response.data


class AsyncVisionClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._raw_client = AsyncRawVisionClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> AsyncRawVisionClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        AsyncRawVisionClient
        """
        return self._raw_client

    async def analyze_image(
        self,
        *,
        image_file: core.File,
        schema: str,
        organization_id: str,
        prompt: typing.Optional[str] = OMIT,
        model: typing.Optional[str] = OMIT,
        provider: typing.Optional[str] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> ImageAnalyzeResponse:
        """
        Analyze image and extract structured data using OpenAI Vision API.

            **Supported Providers:**
            - `openai`: GPT-5 Vision API (Aug 2025+)

            **Parameters:**
            - `image_file`: Image to analyze (PNG, JPEG, WebP)
            - `schema`: JSON schema defining extraction structure
            - `organization_id`: Organization ID (org_ prefixed string)
            - `prompt`: Optional custom instructions (e.g., "Focus on text in the center", "Ignore watermarks")
            - `model`: GPT-5 model to use (gpt-5 standard, gpt-5.1 latest, gpt-5-turbo fast, gpt-5-mini cost-effective)
            - `provider`: Provider to use (currently only openai)

            **Model Selection (GPT-5 Series Only):**
            - `gpt-5`: Standard model - best balance of quality and speed (~$0.03 per image)
            - `gpt-5.1`: Latest iteration (Nov 2025) - faster, customizable personalities (~$0.03 per image)
            - `gpt-5-turbo`: Optimized for speed while maintaining quality (~$0.02 per image)
            - `gpt-5-mini`: Fast and cost-effective for simple tasks (~$0.01 per image)

            **Use Cases:**
            - Extract data from photos
            - Analyze screenshots
            - Process scanned documents
            - OCR with structured output
            - Invoice/receipt processing

            **Billing:**
            - Cost: ~$0.01-0.03 per image (depends on GPT-5 variant)
            - Tracked through usage_events system

            **Response Headers:**
            - `X-Provider`: Provider that processed the request
            - `X-Model-Used`: Actual model used
            - `X-Cost-CHF`: Total cost in CHF

        Parameters
        ----------
        image_file : core.File
            See core.File for more documentation

        schema : str
            JSON schema defining extraction structure

        organization_id : str
            Organization ID (org_ prefixed string)

        prompt : typing.Optional[str]
            Optional custom instructions for analysis

        model : typing.Optional[str]
            GPT-5 model to use (gpt-5 standard, gpt-5.1 latest, gpt-5-turbo fast, gpt-5-mini cost-effective)

        provider : typing.Optional[str]
            Provider to use (currently only openai)

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ImageAnalyzeResponse
            Image analyzed successfully

        Examples
        --------
        import asyncio

        from aitronos import AsyncAitronos

        client = AsyncAitronos(
            api_key="YOUR_API_KEY",
            token="YOUR_TOKEN",
        )


        async def main() -> None:
            await client.vision.analyze_image(
                schema="schema",
                organization_id="organization_id",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.analyze_image(
            image_file=image_file,
            schema=schema,
            organization_id=organization_id,
            prompt=prompt,
            model=model,
            provider=provider,
            request_options=request_options,
        )
        return _response.data



# This file was auto-generated by Fern from our API Definition.

import typing

from .. import core
from ..core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ..core.request_options import RequestOptions
from .raw_client import AsyncRawImageOperationsClient, RawImageOperationsClient

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class ImageOperationsClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._raw_client = RawImageOperationsClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> RawImageOperationsClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        RawImageOperationsClient
        """
        return self._raw_client

    def list_image_models(
        self,
        *,
        provider: typing.Optional[str] = None,
        capability: typing.Optional[str] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> typing.Dict[str, typing.Any]:
        """
        Get a list of available image generation and manipulation models.

            Returns information about all supported image models including:
            - Model capabilities (generation, editing, analysis)
            - Supported resolutions and aspect ratios
            - Provider information
            - Format support

            **Authentication:**
            - Requires either Bearer token or X-API-Key header

            **Query Parameters:**
            - `provider`: Filter by provider (clipdrop, openai, google)
            - `capability`: Filter by capability (text_to_image, image_editing, image_analysis, etc.)

        Parameters
        ----------
        provider : typing.Optional[str]

        capability : typing.Optional[str]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        typing.Dict[str, typing.Any]
            List of available image models

        Examples
        --------
        from aitronos import Aitronos

        client = Aitronos(
            api_key="YOUR_API_KEY",
            token="YOUR_TOKEN",
        )
        client.image_operations.list_image_models()
        """
        _response = self._raw_client.list_image_models(
            provider=provider, capability=capability, request_options=request_options
        )
        return _response.data

    def remove_background(
        self,
        *,
        provider: str,
        organization_id: str,
        image_file: core.File,
        transparency_handling: typing.Optional[str] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> typing.Iterator[bytes]:
        """
        Remove background from an image using Clipdrop.

            **Supported Providers:**
            - `clipdrop`: Removes background and returns transparent PNG

            **Provider-Specific Notes:**
            - OpenAI does not support this operation (returns 422 error)
            - Clipdrop returns PNG with transparency

            **Response Headers:**
            - `X-Provider`: Provider that processed the request
            - `X-Provider-Request-Id`: Provider's request ID (if available)
            - `X-Provider-Credits-Consumed`: Credits consumed (Clipdrop only)

        Parameters
        ----------
        provider : str
            Provider name (must be 'clipdrop')

        organization_id : str
            Organization ID (org_ prefixed string)

        image_file : core.File
            See core.File for more documentation

        transparency_handling : typing.Optional[str]
            Transparency handling mode for Clipdrop

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration. You can pass in configuration such as `chunk_size`, and more to customize the request and response.

        Returns
        -------
        typing.Iterator[bytes]
            Background removed successfully
        """
        with self._raw_client.remove_background(
            provider=provider,
            organization_id=organization_id,
            image_file=image_file,
            transparency_handling=transparency_handling,
            request_options=request_options,
        ) as r:
            yield from r.data

    def remove_text(
        self,
        *,
        provider: str,
        organization_id: str,
        image_file: core.File,
        mask_file: typing.Optional[core.File] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> typing.Iterator[bytes]:
        """
        Remove text overlays from an image.

            **Supported Providers:**
            - `clipdrop`: Removes text automatically
            - `openai`: Removes text using mask-based editing (requires mask_file)

            **Provider-Specific Requirements:**
            - **Clipdrop**: No mask required
            - **OpenAI**: Requires mask_file (PNG with alpha channel), mask dimensions must match image

            **Response Headers:**
            - `X-Provider`: Provider that processed the request
            - `X-Provider-Request-Id`: Provider's request ID (if available)
            - `X-Provider-Credits-Consumed`: Credits consumed (Clipdrop only)

        Parameters
        ----------
        provider : str
            Provider name ('clipdrop' or 'openai')

        organization_id : str
            Organization ID (org_ prefixed string)

        image_file : core.File
            See core.File for more documentation

        mask_file : typing.Optional[core.File]
            See core.File for more documentation

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration. You can pass in configuration such as `chunk_size`, and more to customize the request and response.

        Returns
        -------
        typing.Iterator[bytes]
            Text removed successfully
        """
        with self._raw_client.remove_text(
            provider=provider,
            organization_id=organization_id,
            image_file=image_file,
            mask_file=mask_file,
            request_options=request_options,
        ) as r:
            yield from r.data

    def cleanup(
        self,
        *,
        provider: str,
        organization_id: str,
        image_file: core.File,
        mask_file: typing.Optional[core.File] = OMIT,
        mode: typing.Optional[str] = OMIT,
        prompt: typing.Optional[str] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> typing.Iterator[bytes]:
        """
        Remove or replace objects in an image using mask-based editing.

            **Supported Providers:**
            - `clipdrop`: Mask-based cleanup with optional mode parameter
            - `openai`: Mask-based editing with optional prompt

            **Provider-Specific Parameters:**
            - **Clipdrop**: `mode` can be 'fast' or 'quality'
            - **OpenAI**: `prompt` describes desired changes, mask must be PNG with alpha channel

            **Requirements:**
            - Both `image_file` and `mask_file` are required
            - For OpenAI: mask dimensions must match image dimensions

            **Response Headers:**
            - `X-Provider`: Provider that processed the request
            - `X-Provider-Request-Id`: Provider's request ID (if available)
            - `X-Provider-Credits-Consumed`: Credits consumed (Clipdrop only)

        Parameters
        ----------
        provider : str
            Provider name ('clipdrop' or 'openai')

        organization_id : str
            Organization ID (org_ prefixed string)

        image_file : core.File
            See core.File for more documentation

        mask_file : typing.Optional[core.File]
            See core.File for more documentation

        mode : typing.Optional[str]
            Mode for Clipdrop ('fast' or 'quality')

        prompt : typing.Optional[str]
            Prompt for OpenAI/Google describing desired changes

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration. You can pass in configuration such as `chunk_size`, and more to customize the request and response.

        Returns
        -------
        typing.Iterator[bytes]
            Cleanup completed successfully
        """
        with self._raw_client.cleanup(
            provider=provider,
            organization_id=organization_id,
            image_file=image_file,
            mask_file=mask_file,
            mode=mode,
            prompt=prompt,
            request_options=request_options,
        ) as r:
            yield from r.data

    def replace_background(
        self,
        *,
        provider: str,
        organization_id: str,
        image_file: core.File,
        mask_file: typing.Optional[core.File] = OMIT,
        prompt: typing.Optional[str] = OMIT,
        accept: typing.Optional[str] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> typing.Iterator[bytes]:
        """
        Replace the background of an image with a new scene.

            **Supported Providers:**
            - `clipdrop`: Automatic background replacement with optional prompt
            - `openai`: Mask-based background replacement (requires mask_file)

            **Provider-Specific Requirements:**
            - **Clipdrop**: Optional `prompt` and `accept` header for output format
            - **OpenAI**: Requires `mask_file` (PNG with alpha channel) and `prompt`

            **Output Formats (Clipdrop):**
            - `image/png` (default)
            - `image/webp`
            - `image/jpeg`

            **Response Headers:**
            - `X-Provider`: Provider that processed the request
            - `X-Provider-Request-Id`: Provider's request ID (if available)
            - `X-Provider-Credits-Consumed`: Credits consumed (Clipdrop only)

        Parameters
        ----------
        provider : str
            Provider name ('clipdrop' or 'openai')

        organization_id : str
            Organization ID (org_ prefixed string)

        image_file : core.File
            See core.File for more documentation

        mask_file : typing.Optional[core.File]
            See core.File for more documentation

        prompt : typing.Optional[str]
            Prompt for background generation

        accept : typing.Optional[str]
            Accept header for Clipdrop response format (image/png, image/webp, image/jpeg)

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration. You can pass in configuration such as `chunk_size`, and more to customize the request and response.

        Returns
        -------
        typing.Iterator[bytes]
            Background replaced successfully
        """
        with self._raw_client.replace_background(
            provider=provider,
            organization_id=organization_id,
            image_file=image_file,
            mask_file=mask_file,
            prompt=prompt,
            accept=accept,
            request_options=request_options,
        ) as r:
            yield from r.data

    def generate(
        self,
        *,
        provider: str,
        organization_id: str,
        prompt: str,
        size: typing.Optional[str] = OMIT,
        model: typing.Optional[str] = OMIT,
        aspect_ratio: typing.Optional[str] = OMIT,
        image_size: typing.Optional[str] = OMIT,
        quality: typing.Optional[str] = OMIT,
        style: typing.Optional[str] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> typing.Iterator[bytes]:
        """
        Generate an image from a text prompt using AI.

            **Supported Providers:**
            - `clipdrop`: Text-to-image generation
            - `openai`: Text-to-image generation with GPT Image models
            - `gemini`: Text-to-image generation with Nano Banana models

            **Provider-Specific Parameters:**
            - **Clipdrop**: Prompt max 1000 characters
            - **OpenAI**: Optional `size` parameter (1024x1024, 1024x1536, or 1536x1024), `model`, `quality`, `style`
            - **Gemini**: Optional `aspect_ratio` (1:1, 16:9, etc.), `image_size` (1K, 2K, 4K), `model`

            **Response Headers:**
            - `X-Provider`: Provider that processed the request
            - `X-Provider-Request-Id`: Provider's request ID (if available)
            - `X-Provider-Credits-Consumed`: Credits consumed (Clipdrop only)

        Parameters
        ----------
        provider : str
            Provider name ('clipdrop', 'openai', or 'google')

        organization_id : str
            Organization ID (org_ prefixed string)

        prompt : str
            Text prompt for image generation (max 1000 chars for Clipdrop)

        size : typing.Optional[str]
            Size parameter for OpenAI (1024x1024, 1024x1536, or 1536x1024)

        model : typing.Optional[str]
            Model to use (OpenAI: dall-e-2, dall-e-3, gpt-image-1.5; Gemini: gemini-2.5-flash-image, gemini-3-pro-image-preview)

        aspect_ratio : typing.Optional[str]
            Aspect ratio for Gemini (1:1, 16:9, 9:16, etc.)

        image_size : typing.Optional[str]
            Image size for Gemini (1K, 2K, 4K)

        quality : typing.Optional[str]
            Quality level (standard, hd, low, medium, high, auto)

        style : typing.Optional[str]
            Artistic style for OpenAI (vivid, natural)

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration. You can pass in configuration such as `chunk_size`, and more to customize the request and response.

        Returns
        -------
        typing.Iterator[bytes]
            Image generated successfully

        Examples
        --------
        from aitronos import Aitronos

        client = Aitronos(
            api_key="YOUR_API_KEY",
            token="YOUR_TOKEN",
        )
        client.image_operations.generate(
            provider="provider",
            organization_id="organization_id",
            prompt="prompt",
        )
        """
        with self._raw_client.generate(
            provider=provider,
            organization_id=organization_id,
            prompt=prompt,
            size=size,
            model=model,
            aspect_ratio=aspect_ratio,
            image_size=image_size,
            quality=quality,
            style=style,
            request_options=request_options,
        ) as r:
            yield from r.data

    def uncrop(
        self,
        *,
        provider: str,
        organization_id: str,
        image_file: core.File,
        extend_left: typing.Optional[int] = OMIT,
        extend_right: typing.Optional[int] = OMIT,
        extend_up: typing.Optional[int] = OMIT,
        extend_down: typing.Optional[int] = OMIT,
        seed: typing.Optional[int] = OMIT,
        mask_file: typing.Optional[core.File] = OMIT,
        size: typing.Optional[str] = OMIT,
        prompt: typing.Optional[str] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> typing.Iterator[bytes]:
        """
        Extend an image beyond its original boundaries (uncrop/outpaint).

            **Supported Providers:**
            - `clipdrop`: Extend image with directional parameters
            - `openai`: Outpaint using mask-based editing (requires mask_file)

            **Provider-Specific Parameters:**
            - **Clipdrop**: `extend_left`, `extend_right`, `extend_up`, `extend_down` (max 2000px each), optional `seed`
            - **OpenAI**: Requires `mask_file` (PNG with alpha channel), optional `prompt` and `size`

            **Response Headers:**
            - `X-Provider`: Provider that processed the request
            - `X-Provider-Request-Id`: Provider's request ID (if available)
            - `X-Provider-Credits-Consumed`: Credits consumed (Clipdrop only)

        Parameters
        ----------
        provider : str
            Provider name ('clipdrop' or 'openai')

        organization_id : str
            Organization ID (org_ prefixed string)

        image_file : core.File
            See core.File for more documentation

        extend_left : typing.Optional[int]
            Pixels to extend left (Clipdrop, max 2000)

        extend_right : typing.Optional[int]
            Pixels to extend right (Clipdrop, max 2000)

        extend_up : typing.Optional[int]
            Pixels to extend up (Clipdrop, max 2000)

        extend_down : typing.Optional[int]
            Pixels to extend down (Clipdrop, max 2000)

        seed : typing.Optional[int]
            Random seed for Clipdrop generation

        mask_file : typing.Optional[core.File]
            See core.File for more documentation

        size : typing.Optional[str]
            Size parameter for OpenAI (1024x1024, 1024x1536, or 1536x1024)

        prompt : typing.Optional[str]
            Prompt for OpenAI outpainting

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration. You can pass in configuration such as `chunk_size`, and more to customize the request and response.

        Returns
        -------
        typing.Iterator[bytes]
            Image extended successfully
        """
        with self._raw_client.uncrop(
            provider=provider,
            organization_id=organization_id,
            image_file=image_file,
            extend_left=extend_left,
            extend_right=extend_right,
            extend_up=extend_up,
            extend_down=extend_down,
            seed=seed,
            mask_file=mask_file,
            size=size,
            prompt=prompt,
            request_options=request_options,
        ) as r:
            yield from r.data

    def upscale(
        self,
        *,
        provider: str,
        organization_id: str,
        image_file: core.File,
        target_width: int,
        target_height: int,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> typing.Iterator[bytes]:
        """
        Upscale an image to a higher resolution while maintaining or improving quality.

            **Supported Providers:**
            - `clipdrop`: AI-powered upscaling

            **Provider-Specific Notes:**
            - OpenAI does not support this operation (returns 422 error)
            - Target dimensions must be between 1 and 12000 pixels

            **Response Headers:**
            - `X-Provider`: Provider that processed the request (always 'clipdrop')
            - `X-Provider-Request-Id`: Provider's request ID (if available)
            - `X-Provider-Credits-Consumed`: Credits consumed by Clipdrop

        Parameters
        ----------
        provider : str
            Provider name (must be 'clipdrop')

        organization_id : str
            Organization ID (org_ prefixed string)

        image_file : core.File
            See core.File for more documentation

        target_width : int
            Target width in pixels (1-12000)

        target_height : int
            Target height in pixels (1-12000)

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration. You can pass in configuration such as `chunk_size`, and more to customize the request and response.

        Returns
        -------
        typing.Iterator[bytes]
            Image upscaled successfully
        """
        with self._raw_client.upscale(
            provider=provider,
            organization_id=organization_id,
            image_file=image_file,
            target_width=target_width,
            target_height=target_height,
            request_options=request_options,
        ) as r:
            yield from r.data


class AsyncImageOperationsClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._raw_client = AsyncRawImageOperationsClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> AsyncRawImageOperationsClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        AsyncRawImageOperationsClient
        """
        return self._raw_client

    async def list_image_models(
        self,
        *,
        provider: typing.Optional[str] = None,
        capability: typing.Optional[str] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> typing.Dict[str, typing.Any]:
        """
        Get a list of available image generation and manipulation models.

            Returns information about all supported image models including:
            - Model capabilities (generation, editing, analysis)
            - Supported resolutions and aspect ratios
            - Provider information
            - Format support

            **Authentication:**
            - Requires either Bearer token or X-API-Key header

            **Query Parameters:**
            - `provider`: Filter by provider (clipdrop, openai, google)
            - `capability`: Filter by capability (text_to_image, image_editing, image_analysis, etc.)

        Parameters
        ----------
        provider : typing.Optional[str]

        capability : typing.Optional[str]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        typing.Dict[str, typing.Any]
            List of available image models

        Examples
        --------
        import asyncio

        from aitronos import AsyncAitronos

        client = AsyncAitronos(
            api_key="YOUR_API_KEY",
            token="YOUR_TOKEN",
        )


        async def main() -> None:
            await client.image_operations.list_image_models()


        asyncio.run(main())
        """
        _response = await self._raw_client.list_image_models(
            provider=provider, capability=capability, request_options=request_options
        )
        return _response.data

    async def remove_background(
        self,
        *,
        provider: str,
        organization_id: str,
        image_file: core.File,
        transparency_handling: typing.Optional[str] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> typing.AsyncIterator[bytes]:
        """
        Remove background from an image using Clipdrop.

            **Supported Providers:**
            - `clipdrop`: Removes background and returns transparent PNG

            **Provider-Specific Notes:**
            - OpenAI does not support this operation (returns 422 error)
            - Clipdrop returns PNG with transparency

            **Response Headers:**
            - `X-Provider`: Provider that processed the request
            - `X-Provider-Request-Id`: Provider's request ID (if available)
            - `X-Provider-Credits-Consumed`: Credits consumed (Clipdrop only)

        Parameters
        ----------
        provider : str
            Provider name (must be 'clipdrop')

        organization_id : str
            Organization ID (org_ prefixed string)

        image_file : core.File
            See core.File for more documentation

        transparency_handling : typing.Optional[str]
            Transparency handling mode for Clipdrop

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration. You can pass in configuration such as `chunk_size`, and more to customize the request and response.

        Returns
        -------
        typing.AsyncIterator[bytes]
            Background removed successfully
        """
        async with self._raw_client.remove_background(
            provider=provider,
            organization_id=organization_id,
            image_file=image_file,
            transparency_handling=transparency_handling,
            request_options=request_options,
        ) as r:
            async for _chunk in r.data:
                yield _chunk

    async def remove_text(
        self,
        *,
        provider: str,
        organization_id: str,
        image_file: core.File,
        mask_file: typing.Optional[core.File] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> typing.AsyncIterator[bytes]:
        """
        Remove text overlays from an image.

            **Supported Providers:**
            - `clipdrop`: Removes text automatically
            - `openai`: Removes text using mask-based editing (requires mask_file)

            **Provider-Specific Requirements:**
            - **Clipdrop**: No mask required
            - **OpenAI**: Requires mask_file (PNG with alpha channel), mask dimensions must match image

            **Response Headers:**
            - `X-Provider`: Provider that processed the request
            - `X-Provider-Request-Id`: Provider's request ID (if available)
            - `X-Provider-Credits-Consumed`: Credits consumed (Clipdrop only)

        Parameters
        ----------
        provider : str
            Provider name ('clipdrop' or 'openai')

        organization_id : str
            Organization ID (org_ prefixed string)

        image_file : core.File
            See core.File for more documentation

        mask_file : typing.Optional[core.File]
            See core.File for more documentation

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration. You can pass in configuration such as `chunk_size`, and more to customize the request and response.

        Returns
        -------
        typing.AsyncIterator[bytes]
            Text removed successfully
        """
        async with self._raw_client.remove_text(
            provider=provider,
            organization_id=organization_id,
            image_file=image_file,
            mask_file=mask_file,
            request_options=request_options,
        ) as r:
            async for _chunk in r.data:
                yield _chunk

    async def cleanup(
        self,
        *,
        provider: str,
        organization_id: str,
        image_file: core.File,
        mask_file: typing.Optional[core.File] = OMIT,
        mode: typing.Optional[str] = OMIT,
        prompt: typing.Optional[str] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> typing.AsyncIterator[bytes]:
        """
        Remove or replace objects in an image using mask-based editing.

            **Supported Providers:**
            - `clipdrop`: Mask-based cleanup with optional mode parameter
            - `openai`: Mask-based editing with optional prompt

            **Provider-Specific Parameters:**
            - **Clipdrop**: `mode` can be 'fast' or 'quality'
            - **OpenAI**: `prompt` describes desired changes, mask must be PNG with alpha channel

            **Requirements:**
            - Both `image_file` and `mask_file` are required
            - For OpenAI: mask dimensions must match image dimensions

            **Response Headers:**
            - `X-Provider`: Provider that processed the request
            - `X-Provider-Request-Id`: Provider's request ID (if available)
            - `X-Provider-Credits-Consumed`: Credits consumed (Clipdrop only)

        Parameters
        ----------
        provider : str
            Provider name ('clipdrop' or 'openai')

        organization_id : str
            Organization ID (org_ prefixed string)

        image_file : core.File
            See core.File for more documentation

        mask_file : typing.Optional[core.File]
            See core.File for more documentation

        mode : typing.Optional[str]
            Mode for Clipdrop ('fast' or 'quality')

        prompt : typing.Optional[str]
            Prompt for OpenAI/Google describing desired changes

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration. You can pass in configuration such as `chunk_size`, and more to customize the request and response.

        Returns
        -------
        typing.AsyncIterator[bytes]
            Cleanup completed successfully
        """
        async with self._raw_client.cleanup(
            provider=provider,
            organization_id=organization_id,
            image_file=image_file,
            mask_file=mask_file,
            mode=mode,
            prompt=prompt,
            request_options=request_options,
        ) as r:
            async for _chunk in r.data:
                yield _chunk

    async def replace_background(
        self,
        *,
        provider: str,
        organization_id: str,
        image_file: core.File,
        mask_file: typing.Optional[core.File] = OMIT,
        prompt: typing.Optional[str] = OMIT,
        accept: typing.Optional[str] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> typing.AsyncIterator[bytes]:
        """
        Replace the background of an image with a new scene.

            **Supported Providers:**
            - `clipdrop`: Automatic background replacement with optional prompt
            - `openai`: Mask-based background replacement (requires mask_file)

            **Provider-Specific Requirements:**
            - **Clipdrop**: Optional `prompt` and `accept` header for output format
            - **OpenAI**: Requires `mask_file` (PNG with alpha channel) and `prompt`

            **Output Formats (Clipdrop):**
            - `image/png` (default)
            - `image/webp`
            - `image/jpeg`

            **Response Headers:**
            - `X-Provider`: Provider that processed the request
            - `X-Provider-Request-Id`: Provider's request ID (if available)
            - `X-Provider-Credits-Consumed`: Credits consumed (Clipdrop only)

        Parameters
        ----------
        provider : str
            Provider name ('clipdrop' or 'openai')

        organization_id : str
            Organization ID (org_ prefixed string)

        image_file : core.File
            See core.File for more documentation

        mask_file : typing.Optional[core.File]
            See core.File for more documentation

        prompt : typing.Optional[str]
            Prompt for background generation

        accept : typing.Optional[str]
            Accept header for Clipdrop response format (image/png, image/webp, image/jpeg)

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration. You can pass in configuration such as `chunk_size`, and more to customize the request and response.

        Returns
        -------
        typing.AsyncIterator[bytes]
            Background replaced successfully
        """
        async with self._raw_client.replace_background(
            provider=provider,
            organization_id=organization_id,
            image_file=image_file,
            mask_file=mask_file,
            prompt=prompt,
            accept=accept,
            request_options=request_options,
        ) as r:
            async for _chunk in r.data:
                yield _chunk

    async def generate(
        self,
        *,
        provider: str,
        organization_id: str,
        prompt: str,
        size: typing.Optional[str] = OMIT,
        model: typing.Optional[str] = OMIT,
        aspect_ratio: typing.Optional[str] = OMIT,
        image_size: typing.Optional[str] = OMIT,
        quality: typing.Optional[str] = OMIT,
        style: typing.Optional[str] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> typing.AsyncIterator[bytes]:
        """
        Generate an image from a text prompt using AI.

            **Supported Providers:**
            - `clipdrop`: Text-to-image generation
            - `openai`: Text-to-image generation with GPT Image models
            - `gemini`: Text-to-image generation with Nano Banana models

            **Provider-Specific Parameters:**
            - **Clipdrop**: Prompt max 1000 characters
            - **OpenAI**: Optional `size` parameter (1024x1024, 1024x1536, or 1536x1024), `model`, `quality`, `style`
            - **Gemini**: Optional `aspect_ratio` (1:1, 16:9, etc.), `image_size` (1K, 2K, 4K), `model`

            **Response Headers:**
            - `X-Provider`: Provider that processed the request
            - `X-Provider-Request-Id`: Provider's request ID (if available)
            - `X-Provider-Credits-Consumed`: Credits consumed (Clipdrop only)

        Parameters
        ----------
        provider : str
            Provider name ('clipdrop', 'openai', or 'google')

        organization_id : str
            Organization ID (org_ prefixed string)

        prompt : str
            Text prompt for image generation (max 1000 chars for Clipdrop)

        size : typing.Optional[str]
            Size parameter for OpenAI (1024x1024, 1024x1536, or 1536x1024)

        model : typing.Optional[str]
            Model to use (OpenAI: dall-e-2, dall-e-3, gpt-image-1.5; Gemini: gemini-2.5-flash-image, gemini-3-pro-image-preview)

        aspect_ratio : typing.Optional[str]
            Aspect ratio for Gemini (1:1, 16:9, 9:16, etc.)

        image_size : typing.Optional[str]
            Image size for Gemini (1K, 2K, 4K)

        quality : typing.Optional[str]
            Quality level (standard, hd, low, medium, high, auto)

        style : typing.Optional[str]
            Artistic style for OpenAI (vivid, natural)

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration. You can pass in configuration such as `chunk_size`, and more to customize the request and response.

        Returns
        -------
        typing.AsyncIterator[bytes]
            Image generated successfully

        Examples
        --------
        import asyncio

        from aitronos import AsyncAitronos

        client = AsyncAitronos(
            api_key="YOUR_API_KEY",
            token="YOUR_TOKEN",
        )


        async def main() -> None:
            await client.image_operations.generate(
                provider="provider",
                organization_id="organization_id",
                prompt="prompt",
            )


        asyncio.run(main())
        """
        async with self._raw_client.generate(
            provider=provider,
            organization_id=organization_id,
            prompt=prompt,
            size=size,
            model=model,
            aspect_ratio=aspect_ratio,
            image_size=image_size,
            quality=quality,
            style=style,
            request_options=request_options,
        ) as r:
            async for _chunk in r.data:
                yield _chunk

    async def uncrop(
        self,
        *,
        provider: str,
        organization_id: str,
        image_file: core.File,
        extend_left: typing.Optional[int] = OMIT,
        extend_right: typing.Optional[int] = OMIT,
        extend_up: typing.Optional[int] = OMIT,
        extend_down: typing.Optional[int] = OMIT,
        seed: typing.Optional[int] = OMIT,
        mask_file: typing.Optional[core.File] = OMIT,
        size: typing.Optional[str] = OMIT,
        prompt: typing.Optional[str] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> typing.AsyncIterator[bytes]:
        """
        Extend an image beyond its original boundaries (uncrop/outpaint).

            **Supported Providers:**
            - `clipdrop`: Extend image with directional parameters
            - `openai`: Outpaint using mask-based editing (requires mask_file)

            **Provider-Specific Parameters:**
            - **Clipdrop**: `extend_left`, `extend_right`, `extend_up`, `extend_down` (max 2000px each), optional `seed`
            - **OpenAI**: Requires `mask_file` (PNG with alpha channel), optional `prompt` and `size`

            **Response Headers:**
            - `X-Provider`: Provider that processed the request
            - `X-Provider-Request-Id`: Provider's request ID (if available)
            - `X-Provider-Credits-Consumed`: Credits consumed (Clipdrop only)

        Parameters
        ----------
        provider : str
            Provider name ('clipdrop' or 'openai')

        organization_id : str
            Organization ID (org_ prefixed string)

        image_file : core.File
            See core.File for more documentation

        extend_left : typing.Optional[int]
            Pixels to extend left (Clipdrop, max 2000)

        extend_right : typing.Optional[int]
            Pixels to extend right (Clipdrop, max 2000)

        extend_up : typing.Optional[int]
            Pixels to extend up (Clipdrop, max 2000)

        extend_down : typing.Optional[int]
            Pixels to extend down (Clipdrop, max 2000)

        seed : typing.Optional[int]
            Random seed for Clipdrop generation

        mask_file : typing.Optional[core.File]
            See core.File for more documentation

        size : typing.Optional[str]
            Size parameter for OpenAI (1024x1024, 1024x1536, or 1536x1024)

        prompt : typing.Optional[str]
            Prompt for OpenAI outpainting

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration. You can pass in configuration such as `chunk_size`, and more to customize the request and response.

        Returns
        -------
        typing.AsyncIterator[bytes]
            Image extended successfully
        """
        async with self._raw_client.uncrop(
            provider=provider,
            organization_id=organization_id,
            image_file=image_file,
            extend_left=extend_left,
            extend_right=extend_right,
            extend_up=extend_up,
            extend_down=extend_down,
            seed=seed,
            mask_file=mask_file,
            size=size,
            prompt=prompt,
            request_options=request_options,
        ) as r:
            async for _chunk in r.data:
                yield _chunk

    async def upscale(
        self,
        *,
        provider: str,
        organization_id: str,
        image_file: core.File,
        target_width: int,
        target_height: int,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> typing.AsyncIterator[bytes]:
        """
        Upscale an image to a higher resolution while maintaining or improving quality.

            **Supported Providers:**
            - `clipdrop`: AI-powered upscaling

            **Provider-Specific Notes:**
            - OpenAI does not support this operation (returns 422 error)
            - Target dimensions must be between 1 and 12000 pixels

            **Response Headers:**
            - `X-Provider`: Provider that processed the request (always 'clipdrop')
            - `X-Provider-Request-Id`: Provider's request ID (if available)
            - `X-Provider-Credits-Consumed`: Credits consumed by Clipdrop

        Parameters
        ----------
        provider : str
            Provider name (must be 'clipdrop')

        organization_id : str
            Organization ID (org_ prefixed string)

        image_file : core.File
            See core.File for more documentation

        target_width : int
            Target width in pixels (1-12000)

        target_height : int
            Target height in pixels (1-12000)

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration. You can pass in configuration such as `chunk_size`, and more to customize the request and response.

        Returns
        -------
        typing.AsyncIterator[bytes]
            Image upscaled successfully
        """
        async with self._raw_client.upscale(
            provider=provider,
            organization_id=organization_id,
            image_file=image_file,
            target_width=target_width,
            target_height=target_height,
            request_options=request_options,
        ) as r:
            async for _chunk in r.data:
                yield _chunk
